@@ -1,13 +1,13 @@
 <?php
 /*
 	This is Textpattern
-	Copyright 2005 by Dean Allen 
+	Copyright 2005 by Dean Allen
  	All rights reserved.
 
-	Use of this software indicates acceptance of the Textpattern license agreement 
+	Use of this software indicates acceptance of the Textpattern license agreement
 
-$HeadURL: http://svn.textpattern.com/releases/4.0.6/source/textpattern/include/txp_article.php $
-$LastChangedRevision: 2680 $
+$HeadURL: https://textpattern.googlecode.com/svn/releases/4.2.0/source/textpattern/include/txp_article.php $
+$LastChangedRevision: 3246 $
 
 */
 
@@ -17,12 +17,17 @@ global $vars, $statuses;
 
 $vars = array(
 	'ID','Title','Title_html','Body','Body_html','Excerpt','textile_excerpt','Image',
-	'textile_body', 'Keywords','Status','Posted','Section','Category1','Category2',
+	'textile_body', 'Keywords','Status','Posted','Expires','Section','Category1','Category2',
 	'Annotate','AnnotateInvite','publish_now','reset_time','AuthorID','sPosted',
 	'LastModID','sLastMod','override_form','from_view','year','month','day','hour',
-	'minute','second','url_title','custom_1','custom_2','custom_3','custom_4','custom_5',
-	'custom_6','custom_7','custom_8','custom_9','custom_10'
+	'minute','second','url_title','exp_year','exp_month','exp_day','exp_hour',
+	'exp_minute','exp_second','sExpires'
 );
+$x = get_pref('max_custom_fields', 10);
+for($i = 1; $i <= $x; $i++)
+{
+	$vars[] = "custom_$i";
+}
 
 $statuses = array(
 		1 => gTxt('draft'),
@@ -42,13 +47,14 @@ if (!empty($event) and $event == 'article') {
 	$publish = gps('publish');
 	if ($publish) $step = 'publish';
 
-		
+
 	switch(strtolower($step)) {
 		case "":         article_edit();    break;
 		case "create":   article_edit();    break;
 		case "publish":  article_post();    break;
 		case "edit":     article_edit();    break;
 		case "save":     article_save();    break;
+		case "save_pane_state":     article_save_pane_state();    break;
 	}
 }
 
@@ -56,7 +62,7 @@ if (!empty($event) and $event == 'article') {
 
 	function article_post()
 	{
-		global $txp_user, $vars, $txpcfg, $prefs;		
+		global $txp_user, $vars, $txpcfg, $prefs;
 
 		extract($prefs);
 
@@ -73,18 +79,63 @@ if (!empty($event) and $event == 'article') {
 
 		if ($publish_now==1) {
 			$when = 'now()';
+			$when_ts = time();
 		} else {
-			$when = strtotime($year.'-'.$month.'-'.$day.' '.$hour.':'.$minute.':'.$second)-tz_offset();
+			if (!is_numeric($year) || !is_numeric($month) || !is_numeric($day) || !is_numeric($hour)  || !is_numeric($minute) || !is_numeric($second) ) {
+				article_edit(array(gTxt('invalid_postdate'), E_ERROR));
+				return;
+			}
+
+			$ts = strtotime($year.'-'.$month.'-'.$day.' '.$hour.':'.$minute.':'.$second);
+
+			if ($ts === false || $ts === -1) { // Tracking the PHP meanders on how to return an error
+				article_edit(array(gTxt('invalid_postdate'), E_ERROR));
+				return;
+			}
+
+			$when = $when_ts = $ts - tz_offset($ts);
 			$when = "from_unixtime($when)";
 		}
-		
+
 		$Keywords = doSlash(trim(preg_replace('/( ?[\r\n\t,])+ ?/s', ',', preg_replace('/ +/', ' ', ps('Keywords'))), ', '));
 
+		if (empty($exp_year)) {
+			$expires = 0;
+			$whenexpires = NULLDATETIME;
+		}
+		else {
+			if(empty($exp_month)) $exp_month=1;
+			if(empty($exp_day)) $exp_day=1;
+			if(empty($exp_hour)) $exp_hour=0;
+			if(empty($exp_minute)) $exp_minute=0;
+			if(empty($exp_second)) $exp_second=0;
+
+			$ts = strtotime($exp_year.'-'.$exp_month.'-'.$exp_day.' '.$exp_hour.':'.$exp_minute.':'.$exp_second);
+			$expires = $ts - tz_offset($ts);
+			$whenexpires = "from_unixtime($expires)";
+		}
+
+		if ($expires) {
+			if ($expires <= $when_ts) {
+				article_edit(array(gTxt('article_expires_before_postdate'), E_ERROR));
+				return;
+			}
+		}
+
 		if ($Title or $Body or $Excerpt) {
 
 			if (!has_privs('article.publish') && $Status>=4) $Status = 3;
 			if (empty($url_title)) $url_title = stripSpace($Title_plain, 1);
 
+			$max = get_pref('max_custom_fields', 10);
+			$cfq = array();
+			for ($i = 1; $i <= $max; $i++)
+			{
+				$custom_x = "custom_{$i}";
+				$cfq[] = "custom_$i = '".$$custom_x."'";
+			}
+			$cfq = join(', ', $cfq);
+
 			safe_insert(
 			   "textpattern",
 			   "Title           = '$Title',
@@ -96,8 +147,10 @@ if (!empty($event) and $event == 'article') {
 				Keywords        = '$Keywords',
 				Status          =  $Status,
 				Posted          =  $when,
-				LastMod         =  now(),
+				Expires         =  $whenexpires,
 				AuthorID        = '$txp_user',
+				LastMod         =  $when,
+				LastModID       = '$txp_user',
 				Section         = '$Section',
 				Category1       = '$Category1',
 				Category2       = '$Category2',
@@ -107,30 +160,22 @@ if (!empty($event) and $event == 'article') {
 				override_form   = '$override_form',
 				url_title       = '$url_title',
 				AnnotateInvite  = '$AnnotateInvite',
-				custom_1        = '$custom_1',
-				custom_2        = '$custom_2',
-				custom_3        = '$custom_3',
-				custom_4        = '$custom_4',
-				custom_5        = '$custom_5',
-				custom_6        = '$custom_6',
-				custom_7        = '$custom_7',
-				custom_8        = '$custom_8',
-				custom_9        = '$custom_9',
-				custom_10       = '$custom_10',
+				$cfq,
 				uid             = '".md5(uniqid(rand(),true))."',
 				feed_time       = now()"
 			);
-			
+
 			$GLOBALS['ID'] = mysql_insert_id();
-				
+
 			if ($Status>=4) {
-				
+
 				do_pings();
-				
+
 				update_lastmod();
 			}
+			$s = check_url_title($url_title);
 			article_edit(
-				get_status_message($Status).check_url_title($url_title)
+				array(get_status_message($Status).' '.$s, ($s ? E_WARNING : 0))
 			);
 		} else article_edit();
 	}
@@ -145,40 +190,80 @@ if (!empty($event) and $event == 'article') {
 
 		$incoming = psa($vars);
 
-		$oldArticle = safe_row('Status, url_title, Title','textpattern','ID = '.(int)$incoming['ID']);
+		$oldArticle = safe_row('Status, url_title, Title, unix_timestamp(LastMod) as sLastMod, LastModID','textpattern','ID = '.(int)$incoming['ID']);
 
 		if (! (    ($oldArticle['Status'] >= 4 and has_privs('article.edit.published'))
 				or ($oldArticle['Status'] >= 4 and $incoming['AuthorID']==$txp_user and has_privs('article.edit.own.published'))
 		    	or ($oldArticle['Status'] < 4 and has_privs('article.edit'))
 				or ($oldArticle['Status'] < 4 and $incoming['AuthorID']==$txp_user and has_privs('article.edit.own'))))
 		{
-				// Not allowed, you silly rabbit, you shouldn't even be here. 
+				// Not allowed, you silly rabbit, you shouldn't even be here.
 				// Show default editing screen.
 			article_edit();
 			return;
 		}
 
+		if ($oldArticle['sLastMod'] != $incoming['sLastMod'])
+		{
+			article_edit(array(gTxt('concurrent_edit_by', array('{author}' => htmlspecialchars($oldArticle['LastModID']))), E_ERROR), TRUE);
+			return;
+		}
+
 		$incoming = textile_main_fields($incoming, $use_textile);
 
 		extract(doSlash($incoming));
-		extract(array_map('assert_int', psa(array('ID', 'Status', 'textile_body', 'textile_excerpt'))));  
+		extract(array_map('assert_int', psa(array('ID', 'Status', 'textile_body', 'textile_excerpt'))));
 
 		$Annotate = (int) $Annotate;
 
 		if (!has_privs('article.publish') && $Status>=4) $Status = 3;
 
 		if($reset_time) {
-			$whenposted = "Posted=now()"; 
+			$whenposted = "Posted=now()";
+			$when_ts = time();
 		} else {
-			$when = strtotime($year.'-'.$month.'-'.$day.' '.$hour.':'.$minute.':'.$second)-tz_offset();
-			$when = "from_unixtime($when)";
-			$whenposted = "Posted=$when";
+			if (!is_numeric($year) || !is_numeric($month) || !is_numeric($day) || !is_numeric($hour)  || !is_numeric($minute) || !is_numeric($second) ) {
+				article_edit(array(gTxt('invalid_postdate'), E_ERROR));
+				return;
+			}
+
+			$ts = strtotime($year.'-'.$month.'-'.$day.' '.$hour.':'.$minute.':'.$second);
+
+			if ($ts === false || $ts === -1) {
+				article_edit(array(gTxt('invalid_postdate'), E_ERROR));
+				return;
+			}
+
+			$when = $when_ts = $ts - tz_offset($ts);
+			$whenposted = "Posted=from_unixtime($when)";
+		}
+
+		if (empty($exp_year)) {
+			$expires = 0;
+			$whenexpires = "Expires=".NULLDATETIME;
+		} else {
+			if(empty($exp_month)) $exp_month=1;
+			if(empty($exp_day)) $exp_day=1;
+			if(empty($exp_hour)) $exp_hour=0;
+			if(empty($exp_minute)) $exp_minute=0;
+			if(empty($exp_second)) $exp_second=0;
+
+			$ts = strtotime($exp_year.'-'.$exp_month.'-'.$exp_day.' '.$exp_hour.':'.$exp_minute.':'.$exp_second);
+			$expires = $ts - tz_offset($ts);
+			$whenexpires = "Expires=from_unixtime($expires)";
+		}
+
+		if ($expires) {
+			if ($expires <= $when_ts) {
+				article_edit(array(gTxt('article_expires_before_postdate'), E_ERROR));
+				return;
+			}
 		}
 
 		//Auto-Update custom-titles according to Title, as long as unpublished and NOT customized
 		if ( empty($url_title)
-			  || ( ($oldArticle['Status'] < 4) 
-					&& ($oldArticle['url_title'] == $url_title ) 
+			  || ( ($oldArticle['Status'] < 4)
+					&& ($oldArticle['url_title'] == $url_title )
 					&& ($oldArticle['url_title'] == stripSpace($oldArticle['Title'],1))
 					&& ($oldArticle['Title'] != $Title)
 				 )
@@ -189,7 +274,16 @@ if (!empty($event) and $event == 'article') {
 
 		$Keywords = doSlash(trim(preg_replace('/( ?[\r\n\t,])+ ?/s', ',', preg_replace('/ +/', ' ', ps('Keywords'))), ', '));
 
-		safe_update("textpattern", 
+		$max = get_pref('max_custom_fields', 10);
+		$cfq = array();
+		for ($i = 1; $i <= $max; $i++)
+		{
+			$custom_x = "custom_{$i}";
+			$cfq[] = "custom_$i = '".$$custom_x."'";
+		}
+		$cfq = join(', ', $cfq);
+
+		safe_update("textpattern",
 		   "Title           = '$Title',
 			Body            = '$Body',
 			Body_html       = '$Body_html',
@@ -209,36 +303,28 @@ if (!empty($event) and $event == 'article') {
 			override_form   = '$override_form',
 			url_title       = '$url_title',
 			AnnotateInvite  = '$AnnotateInvite',
-			custom_1        = '$custom_1',
-			custom_2        = '$custom_2',
-			custom_3        = '$custom_3',
-			custom_4        = '$custom_4',
-			custom_5        = '$custom_5',
-			custom_6        = '$custom_6',
-			custom_7        = '$custom_7',
-			custom_8        = '$custom_8',
-			custom_9        = '$custom_9',
-			custom_10       = '$custom_10',
-			$whenposted",
+			$cfq,
+			$whenposted,
+			$whenexpires",
 			"ID = $ID"
 		);
 
 		if($Status >= 4) {
 			if ($oldArticle['Status'] < 4) {
-				do_pings();	
+				do_pings();
 			}
 			update_lastmod();
 		}
-		
-		article_edit(
-			get_status_message($Status).check_url_title($url_title)
-		);
 
+		$s = check_url_title($url_title);
+		article_edit(
+			array(get_status_message($Status).' '.$s, ($s ? E_WARNING : 0))
+		);
 	}
 
 //--------------------------------------------------------------
 
-	function article_edit($message = '')
+	function article_edit($message = '', $concurrent = FALSE)
 	{
 		global $vars, $txp_user, $comments_disabled_after, $txpcfg, $prefs;
 
@@ -249,7 +335,7 @@ if (!empty($event) and $event == 'article') {
 		if(!empty($GLOBALS['ID'])) { // newly-saved article
 			$ID = $GLOBALS['ID'];
 			$step = 'edit';
-		} else {  
+		} else {
 			$ID = gps('ID');
 		}
 
@@ -260,27 +346,29 @@ if (!empty($event) and $event == 'article') {
 		if(!$view || gps('save') || gps('publish')) {
 			$view = 'text';
 		}
-		
+
 		if (!$step) $step = "create";
 
-		if ($step == "edit" 
-			&& $view=="text" 
-			&& !empty($ID) 
-			&& $from_view != 'preview' 
-			&& $from_view != 'html') {
-
+		if ($step == "edit"
+			&& $view=="text"
+			&& !empty($ID)
+			&& $from_view != 'preview'
+			&& $from_view != 'html'
+			&& !$concurrent)
+		{
 			$pull = true;          //-- it's an existing article - off we go to the db
 			$ID = assert_int($ID);
 
 			$rs = safe_row(
 				"*, unix_timestamp(Posted) as sPosted,
+				unix_timestamp(Expires) as sExpires,
 				unix_timestamp(LastMod) as sLastMod",
-				"textpattern", 
+				"textpattern",
 				"ID=$ID"
 			);
 
 			extract($rs);
-			$reset_time = $publish_now = ($Status < 4);
+			$reset_time = $publish_now = ($Status < 4) && ($sPosted <= time());
 
 		} else {
 
@@ -297,11 +385,17 @@ if (!empty($event) and $event == 'article') {
 				}
 			}
 
-			else 
+			else
 			{
 				$store_out = gpsa($vars);
+
+				if ($concurrent)
+				{
+					$store_out['sLastMod'] = safe_field('unix_timestamp(LastMod) as sLastMod', 'textpattern', 'ID='.$ID);
+				}
 			}
 
+			$rs = $store_out;
 			extract($store_out);
 		}
 
@@ -316,9 +410,9 @@ if (!empty($event) and $event == 'article') {
 
 		if ($step!='create') {
 
-			// Previous record?				
+			// Previous record?
 			$prev_id = checkIfNeighbour('prev',$sPosted);
-			
+
 			// Next record?
 			$next_id = checkIfNeighbour('next',$sPosted);
 		}
@@ -349,55 +443,69 @@ if (!empty($event) and $event == 'article') {
 
 		//-- markup help --------------
 
-			echo side_help($textile_body, $textile_excerpt).
+			echo pluggable_ui('article_ui', 'sidehelp', side_help($textile_body, $textile_excerpt));
 
-			'<h3 class="plain"><a href="#advanced" onclick="toggleDisplay(\'advanced\'); return false;">'.gTxt('advanced_options').'</a></h3>',
-			'<div id="advanced" style="display:none;">',
+		//-- custom menu entries --------------
+
+			echo pluggable_ui('article_ui', 'extend_col_1', '', $rs);
+
+		//-- advanced --------------
+
+			echo '<h3 class="plain lever'.(get_pref('pane_article_advanced_visible') ? ' expanded' : '').'"><a href="#advanced">'.gTxt('advanced_options').'</a></h3>'.
+				'<div id="advanced" class="toggle" style="display:'.(get_pref('pane_article_advanced_visible') ? 'block' : 'none').'">';
 
 			// markup selection
+			echo pluggable_ui('article_ui', 'markup',
 				n.graf('<label for="markup-body">'.gTxt('article_markup').'</label>'.br.
-					pref_text('textile_body', $textile_body, 'markup-body')),
-
+					pref_text('textile_body', $textile_body, 'markup-body')).
 				n.graf('<label for="markup-excerpt">'.gTxt('excerpt_markup').'</label>'.br.
 					pref_text('textile_excerpt', $textile_excerpt, 'markup-excerpt')),
+				$rs);
 
-				// form override
-			($allow_form_override)
-			?	graf('<label for="override-form">'.gTxt('override_default_form').'</label>'.br.
-					form_pop($override_form, 'override-form').sp.popHelp('override_form'))
-			:	'',
-			
-				// custom fields, believe it or not
-			($custom_1_set)  ? custField(  1, $custom_1_set,  $custom_1 )    : '',
-			($custom_2_set)  ? custField(  2, $custom_2_set,  $custom_2 )    : '',
-			($custom_3_set)  ? custField(  3, $custom_3_set,  $custom_3 )    : '',
-			($custom_4_set)  ? custField(  4, $custom_4_set,  $custom_4 )    : '',
-			($custom_5_set)  ? custField(  5, $custom_5_set,  $custom_5 )    : '',
-			($custom_6_set)  ? custField(  6, $custom_6_set,  $custom_6 )    : '',
-			($custom_7_set)  ? custField(  7, $custom_7_set,  $custom_7 )    : '',
-			($custom_8_set)  ? custField(  8, $custom_8_set,  $custom_8 )    : '',
-			($custom_9_set)  ? custField(  9, $custom_9_set,  $custom_9 )    : '',
-			($custom_10_set) ? custField( 10, $custom_10_set, $custom_10 )   : '',
+			// form override
+			echo ($allow_form_override)
+				? pluggable_ui('article_ui', 'override', graf('<label for="override-form">'.gTxt('override_default_form').'</label>'.sp.popHelp('override_form').br.
+					form_pop($override_form, 'override-form')), $rs)
+				: '';
+
+			// custom fields, believe it or not
+			$max = get_pref('max_custom_fields', 10);
+			$cf = '';
+			for($i = 1; $i <= $max; $i++)
+			{
+				$custom_x_set = "custom_{$i}_set";
+				$custom_x = "custom_{$i}";
+				$cf .= ($$custom_x_set !== '' ? custField( $i, $$custom_x_set,  $$custom_x ): '');
+			}
+			echo pluggable_ui('article_ui', 'custom_fields', $cf, $rs);
 
 			// keywords
+			echo pluggable_ui('article_ui', 'keywords',
 				n.graf('<label for="keywords">'.gTxt('keywords').'</label>'.sp.popHelp('keywords').br.
 					n.'<textarea id="keywords" name="Keywords" cols="18" rows="5">'.htmlspecialchars(str_replace(',' ,', ', $Keywords)).'</textarea>'),
+				$rs);
 
 			// article image
+			echo pluggable_ui('article_ui', 'article_image',
 				n.graf('<label for="article-image">'.gTxt('article_image').'</label>'.sp.popHelp('article_image').br.
 					fInput('text', 'Image', $Image, 'edit', '', '', 22, '', 'article-image')),
+				$rs);
 
 			// url title
+			echo pluggable_ui('article_ui', 'url_title',
 				n.graf('<label for="url-title">'.gTxt('url_title').'</label>'.sp.popHelp('url_title').br.
 					fInput('text', 'url_title', $url_title, 'edit', '', '', 22, '', 'url-title')),
-		
-			'</div>
-			
-			<h3 class="plain"><a href="#recent" onclick="toggleDisplay(\'recent\'); return false;">'.gTxt('recent_articles').'</a>'.'</h3>'.
-			'<div id="recent" style="display:none;">';
-			
+				$rs);
+
+			echo '</div>'.n;
+
+		//-- recent articles --------------
+
+			echo '<h3 class="plain lever'.(get_pref('pane_article_recent_visible') ? ' expanded' : '').'"><a href="#recent">'.gTxt('recent_articles').'</a>'.'</h3>'.
+				'<div id="recent" class="toggle" style="display:'.(get_pref('pane_article_recent_visible') ? 'block' : 'none').'">';
+
 			$recents = safe_rows_start("Title, ID",'textpattern',"1=1 order by LastMod desc limit 10");
-			
+
 			if ($recents)
 			{
 				echo '<ul class="plain-list">';
@@ -414,7 +522,7 @@ if (!empty($event) and $event == 'article') {
 
 				echo '</ul>';
 			}
-			
+
 			echo '</div>';
 		}
 
@@ -425,7 +533,7 @@ if (!empty($event) and $event == 'article') {
 
 		echo '</td>'.n.'<td id="article-main">';
 
-	//-- title input -------------- 
+	//-- title input --------------
 
 		if ($view == 'preview')
 		{
@@ -439,13 +547,22 @@ if (!empty($event) and $event == 'article') {
 
 		elseif ($view == 'text')
 		{
-			echo '<p><input type="text" id="title" name="Title" value="'.cleanfInput($Title).'" class="edit" size="40" tabindex="1" />';
+			echo  pluggable_ui('article_ui', 'title',
+				n.'<p><label for="title">'.gTxt('title').'</label>'.sp.popHelp('title').br.
+				'<input type="text" id="title" name="Title" value="'.escape_title($Title).'" class="edit" size="40" tabindex="1" />',
+				$rs);
 
-			if ( ($Status == 4 or $Status == 5) and $step != 'create')
+			if ($step != 'create')
 			{
 				include_once txpath.'/publish/taghandlers.php';
+				$url = permlinkurl_id($ID);
 
-				echo sp.sp.'<a href="'.permlinkurl_id($ID).'">'.gTxt('view').'</a>';
+				if ($Status != 4 and $Status != 5)
+				{
+					$url .= (strpos($url, '?') === FALSE ? '?' : '&amp;') . 'txpreview='.intval($ID).'.'.time();
+				}
+
+				echo sp.sp.'<a href="'.$url.'" class="article-view">'.gTxt('view').'</a>';
 			}
 
 			echo '</p>';
@@ -454,7 +571,7 @@ if (!empty($event) and $event == 'article') {
 	//-- body --------------------
 
 		if ($view == 'preview')
-		{ 
+		{
 			if ($textile_body == USE_TEXTILE)
 			{
 				echo $textile->TextileThis($Body);
@@ -493,7 +610,10 @@ if (!empty($event) and $event == 'article') {
 
 		else
 		{
-			echo n.graf('<textarea id="body" name="Body" cols="55" rows="31" tabindex="2">'.htmlspecialchars($Body).'</textarea>');
+			echo pluggable_ui('article_ui', 'body',
+				n.graf('<label for="body">'.gTxt('body').'</label>'.sp.popHelp('body').br.
+				'<textarea id="body" name="Body" cols="55" rows="31" tabindex="2">'.htmlspecialchars($Body).'</textarea>'),
+				$rs);
 		}
 
 	//-- excerpt --------------------
@@ -502,8 +622,10 @@ if (!empty($event) and $event == 'article') {
 		{
 			if ($view == 'text')
 			{
-				echo n.graf('<label for="excerpt">'.gTxt('excerpt').'</label>'.sp.popHelp('excerpt').br.
-					'<textarea id="excerpt" name="Excerpt" cols="55" rows="5" tabindex="3">'.htmlspecialchars($Excerpt).'</textarea>');
+				echo pluggable_ui('article_ui', 'excerpt',
+					n.graf('<label for="excerpt">'.gTxt('excerpt').'</label>'.sp.popHelp('excerpt').br.
+					'<textarea id="excerpt" name="Excerpt" cols="55" rows="5" tabindex="3">'.htmlspecialchars($Excerpt).'</textarea>'),
+					$rs);
 			}
 
 			else
@@ -522,7 +644,7 @@ if (!empty($event) and $event == 'article') {
 
 
 	//-- author --------------
-	
+
 		if ($view=="text" && $step != "create") {
 			echo '<p class="small">'.gTxt('posted_by').': '.htmlspecialchars($AuthorID).' &#183; '.safe_strftime('%d %b %Y &#183; %X',$sPosted);
 			if($sPosted != $sLastMod) {
@@ -533,14 +655,18 @@ if (!empty($event) and $event == 'article') {
 
 		echo hInput('from_view',$view),
 		'</td>';
+
+	//-- layer tabs -------------------
+
 		echo '<td id="article-tabs">';
 
-  	//-- layer tabs -------------------
-
-		echo ($use_textile == USE_TEXTILE || $textile_body == USE_TEXTILE)
-			? graf(tab('text',$view).br.tab('html',$view).br.tab('preview',$view))
-			: '&#160;';
+		echo pluggable_ui('article_ui', 'view',
+			($use_textile == USE_TEXTILE || $textile_body == USE_TEXTILE)
+			? tag((tab('text',$view).tab('html',$view).tab('preview',$view)), 'ul')
+			: '&#160;',
+			$rs);
 		echo '</td>';
+
 		echo '<td id="article-col-2">';
 
 		if ($view == 'text')
@@ -550,7 +676,7 @@ if (!empty($event) and $event == 'article') {
 				echo n.graf(href(gtxt('create_new'), 'index.php?event=article'));
 			}
 
-		//-- prev/next article links -- 
+		//-- prev/next article links --
 
 			if ($step!='create' and ($prev_id or $next_id)) {
 				echo '<p>',
@@ -567,14 +693,17 @@ if (!empty($event) and $event == 'article') {
 
 		//-- status radios --------------
 
-			echo n.n.'<fieldset id="write-status">'.
+			echo pluggable_ui('article_ui', 'status',
+				n.n.'<fieldset id="write-status">'.
 				n.'<legend>'.gTxt('status').'</legend>'.
 				n.status_radio($Status).
-				n.'</fieldset>';
+				n.'</fieldset>',
+				$rs);
 
 		//-- category selects -----------
 
-			echo n.n.'<fieldset id="write-sort">'.
+			echo pluggable_ui('article_ui', 'categories',
+				n.n.'<fieldset id="write-sort">'.
 				n.'<legend>'.gTxt('sort_display').'</legend>'.
 
 				n.graf('<label for="category-1">'.gTxt('category1').'</label> '.
@@ -582,21 +711,23 @@ if (!empty($event) and $event == 'article') {
 					n.category_popup('Category1', $Category1, 'category-1')).
 
 				n.graf('<label for="category-2">'.gTxt('category2').'</label>'.br.
-					n.category_popup('Category2', $Category2, 'category-2'));
+					n.category_popup('Category2', $Category2, 'category-2')),
+				$rs);
 
 		//-- section select --------------
 
 			if(!$from_view && !$pull) $Section = getDefaultSection();
 
-			echo n.graf('<label for="section">'.gTxt('section').'</label> '.
+			echo pluggable_ui('article_ui', 'section',
+				n.graf('<label for="section">'.gTxt('section').'</label> '.
 				'<span class="small">['.eLink('section', '', '', '', gTxt('edit')).']</span>'.br.
 				section_popup($Section, 'section')).
-
-				n.'</fieldset>'.
+				n.'</fieldset>',
+				$rs);
 
 		//-- "More" section
-				n.n.'<h3 class="plain"><a href="#more" onclick="toggleDisplay(\'more\'); return false;">'.gTxt('more').'</a></h3>',
-				'<div id="more" style="display: none;">';
+			echo n.n.'<h3 class="plain lever'.(get_pref('pane_article_more_visible') ? ' expanded' : '').'"><a href="#more">'.gTxt('more').'</a></h3>',
+				'<div id="more" class="toggle" style="display:'.(get_pref('pane_article_more_visible') ? 'block' : 'none').'">';
 
 		//-- comments stuff --------------
 
@@ -608,7 +739,7 @@ if (!empty($event) and $event == 'article') {
 
 			if ($use_comments == 1)
 			{
-				echo n.n.'<fieldset id="write-comments">'.
+				$invite[] = n.n.'<fieldset id="write-comments">'.
 					n.'<legend>'.gTxt('comments').'</legend>';
 
 				$comments_expired = false;
@@ -626,12 +757,12 @@ if (!empty($event) and $event == 'article') {
 
 				if ($comments_expired)
 				{
-					echo n.n.graf(gTxt('expired'));
+					$invite[] = n.n.graf(gTxt('expired'));
 				}
 
 				else
 				{
-					echo n.n.graf(
+					$invite[] = n.n.graf(
 						onoffRadio('Annotate', $Annotate)
 					).
 
@@ -641,19 +772,22 @@ if (!empty($event) and $event == 'article') {
 					);
 				}
 
-				echo n.n.'</fieldset>';
+				$invite[] = n.n.'</fieldset>';
+				echo pluggable_ui('article_ui', 'annotate_invite', join('', $invite), $rs);
+
 			}
 
 			if ($step == "create" and empty($GLOBALS['ID']))
 			{
-		//-- timestamp ------------------- 
+		//-- timestamp -------------------
 
 				//Avoiding modified date to disappear
 				$persist_timestamp = (!empty($store_out['year']))?
 					safe_strtotime($store_out['year'].'-'.$store_out['month'].'-'.$store_out['day'].' '.$store_out['hour'].':'.$store_out['minute'].':'.$store_out['second'])
 					: time();
 
-				echo n.n.'<fieldset id="write-timestamp">'.
+				echo pluggable_ui('article_ui', 'timestamp',
+					n.n.'<fieldset id="write-timestamp">'.
 					n.'<legend>'.gTxt('timestamp').'</legend>'.
 
 					n.graf(checkbox('publish_now', '1', $publish_now, '', 'publish_now').'<label for="publish_now">'.gTxt('set_to_now').'</label>').
@@ -672,10 +806,36 @@ if (!empty($event) and $event == 'article') {
 						tsi('second', '%S', $persist_timestamp)
 					).
 
-				n.'</fieldset>'.
+				n.'</fieldset>',
+				array('sPosted' => $persist_timestamp) + $rs);
+
+		//-- expires -------------------
+
+				$persist_timestamp = (!empty($store_out['exp_year']))?
+					safe_strtotime($store_out['exp_year'].'-'.$store_out['exp_month'].'-'.$store_out['exp_day'].' '.$store_out['exp_hour'].':'.$store_out['exp_minute'].':'.$store_out['second'])
+					: NULLDATETIME;
+
+				echo pluggable_ui('article_ui', 'expires',
+					n.n.'<fieldset id="write-expires">'.
+					n.'<legend>'.gTxt('expires').'</legend>'.
+
+					n.graf(gtxt('date').sp.
+						tsi('exp_year', '%Y', $persist_timestamp).' / '.
+						tsi('exp_month', '%m', $persist_timestamp).' / '.
+						tsi('exp_day', '%d', $persist_timestamp)
+					).
+
+					n.graf(gTxt('time').sp.
+						tsi('exp_hour', '%H', $persist_timestamp).' : '.
+						tsi('exp_minute', '%M', $persist_timestamp).' : '.
+						tsi('exp_second', '%S', $persist_timestamp)
+					).
+
+				n.'</fieldset>',
+				$rs);
 
 				// end "More" section
-				n.n.'</div>';
+				echo n.n.'</div>';
 
 		//-- publish button --------------
 
@@ -688,13 +848,14 @@ if (!empty($event) and $event == 'article') {
 			else
 			{
 
-			//-- timestamp ------------------- 
+			//-- timestamp -------------------
 
 				if (!empty($year)) {
-					$sPosted = safe_strtotime($year.'-'.$month.'-'.$day.' '.$hour.':'.$minute.':'.$second);					
-				}	
-					
-				echo n.n.'<fieldset id="write-timestamp">'.
+					$sPosted = safe_strtotime($year.'-'.$month.'-'.$day.' '.$hour.':'.$minute.':'.$second);
+				}
+
+				echo pluggable_ui('article_ui', 'timestamp',
+					n.n.'<fieldset id="write-timestamp">'.
 					n.'<legend>'.gTxt('timestamp').'</legend>'.
 
 					n.graf(checkbox('reset_time', '1', $reset_time, '', 'reset_time').'<label for="reset_time">'.gTxt('reset_time').'</label>').
@@ -713,15 +874,47 @@ if (!empty($event) and $event == 'article') {
 						tsi('second', '%S', $sPosted)
 					).
 
-					n.hInput('sPosted', $sPosted),
-					n.hInput('sLastMod', $sLastMod),
-					n.hInput('AuthorID', $AuthorID),
-					n.hInput('LastModID', $LastModID),
+					n.hInput('sPosted', $sPosted).
+					n.hInput('sLastMod', $sLastMod).
+					n.hInput('AuthorID', $AuthorID).
+					n.hInput('LastModID', $LastModID).
 
-				n.'</fieldset>'.
+				n.'</fieldset>',
+				$rs);
+
+			//-- expires -------------------
+				if (!empty($exp_year))
+				{
+					if(empty($exp_month)) $exp_month=1;
+					if(empty($exp_day)) $exp_day=1;
+					if(empty($exp_hour)) $exp_hour=0;
+					if(empty($exp_minute)) $exp_minute=0;
+					if(empty($exp_second)) $exp_second=0;
+					$sExpires = safe_strtotime($exp_year.'-'.$exp_month.'-'.$exp_day.' '.$exp_hour.':'.$exp_minute.':'.$exp_second);
+				}
+
+				echo pluggable_ui('article_ui', 'expires',
+					n.n.'<fieldset id="write-expires">'.
+					n.'<legend>'.gTxt('expires').'</legend>'.
+
+					n.graf(gtxt('date').sp.
+						tsi('exp_year', '%Y', $sExpires).' / '.
+						tsi('exp_month', '%m', $sExpires).' / '.
+						tsi('exp_day', '%d', $sExpires)
+					).
+
+					n.graf(gTxt('time').sp.
+						tsi('exp_hour', '%H', $sExpires).' : '.
+						tsi('exp_minute', '%M', $sExpires).' : '.
+						tsi('exp_second', '%S', $sExpires)
+					).
+					n.hInput('sExpires', $sExpires).
+
+				n.'</fieldset>',
+				$rs);
 
 				// end "More" section
-				n.n.'</div>';
+				echo n.n.'</div>';
 
 		//-- save button --------------
 
@@ -733,8 +926,18 @@ if (!empty($event) and $event == 'article') {
 			}
 		}
 
-		echo '</td></tr></table></form>';
-	
+		echo '</td></tr></table></form>'.n;
+		// Assume users would not change the timestamp if they wanted to "publish now"/"reset time"
+		echo script_js( <<<EOS
+		$('#write-timestamp input.edit').change(
+			function() {
+				$('#publish_now').attr('checked', false);
+				$('#reset_time').attr('checked', false);
+			});
+EOS
+);
+
+
 	}
 
 // -------------------------------------------------------------
@@ -749,15 +952,15 @@ if (!empty($event) and $event == 'article') {
 	function checkIfNeighbour($whichway,$sPosted)
 	{
 		$sPosted = assert_int($sPosted);
-		$dir = ($whichway == 'prev') ? '<' : '>'; 
-		$ord = ($whichway == 'prev') ? 'desc' : 'asc'; 
+		$dir = ($whichway == 'prev') ? '<' : '>';
+		$ord = ($whichway == 'prev') ? 'desc' : 'asc';
 
-		return safe_field("ID", "textpattern", 
+		return safe_field("ID", "textpattern",
 			"Posted $dir from_unixtime($sPosted) order by Posted $ord limit 1");
 	}
 
 //--------------------------------------------------------------
-// remember to show markup help for both body and excerpt 
+// remember to show markup help for both body and excerpt
 // if they are different
 
 	function side_help($textile_body, $textile_excerpt)
@@ -765,10 +968,10 @@ if (!empty($event) and $event == 'article') {
 		if ($textile_body == USE_TEXTILE or $textile_excerpt == USE_TEXTILE)
 		{
 			return n.hed(
-				'<a href="#textile_help" onclick="toggleDisplay(\'textile_help\'); return false;">'.gTxt('textile_help').'</a>'
-			, 3, ' class="plain"').
+				'<a href="#textile_help">'.gTxt('textile_help').'</a>'
+			, 3, ' class="plain lever'.(get_pref('pane_article_textile_help_visible') ? ' expanded' : '').'"').
 
-				n.'<div id="textile_help" style="display: none;">'.
+				n.'<div id="textile_help" class="toggle" style="display:'.(get_pref('pane_article_textile_help_visible') ? 'block' : 'none').'">'.
 
 				n.'<ul class="plain-list small">'.
 					n.t.'<li>'.gTxt('header').': <strong>h<em>n</em>.</strong>'.sp.
@@ -807,7 +1010,7 @@ if (!empty($event) and $event == 'article') {
 				, ' class="small"').
 
 				n.graf(
-					'<a href="http://textile.thresholdstate.com/" target="_blank">'.gTxt('More').'</a>').
+					'<a id="textile-docs-link" href="http://textpattern.com/textile-sandbox" target="_blank">'.gTxt('More').'</a>').
 
 				n.'</div>';
 		}
@@ -859,18 +1062,17 @@ if (!empty($event) and $event == 'article') {
 	}
 
 //--------------------------------------------------------------
-	function tab($tabevent,$view) 
+	function tab($tabevent,$view)
 	{
 		$state = ($view==$tabevent) ? 'up' : 'down';
-		$img = 'txp_img/'.$tabevent.$state.'.gif';
-		$out = '<img src="'.$img.'"';
-		$out.=($tabevent!=$view) ? ' onclick="document.article.view.value=\''.$tabevent.'\'; document.article.submit(); return false;"' : "";
-		$out.= ' height="100" width="19" alt="" id="article-tab-'.$tabevent.'" />';
+		$out = "<li id='tab-$tabevent$state'>";
+		$out.=($tabevent!=$view) ? '<a href="javascript:document.article.view.value=\''.$tabevent.'\';document.article.submit();">'.gTxt($tabevent).'</a>' : gTxt($tabevent);
+		$out.='</li>';
 		return $out;
 	}
 
 //--------------------------------------------------------------
-	function getDefaultSection() 
+	function getDefaultSection()
 	{
 		return safe_field("name", "txp_section","is_default=1");
 	}
@@ -925,44 +1127,42 @@ if (!empty($event) and $event == 'article') {
 	function textile_main_fields($incoming, $use_textile)
 	{
 		global $txpcfg;
-		
+
 		include_once txpath.'/lib/classTextile.php';
 		$textile = new Textile();
-		
+
 		$incoming['Title_plain'] = $incoming['Title'];
-		$incoming['url_title'] = preg_replace('|[\x00-\x1f#%+/?\x7f]|', '', $incoming['url_title']);
-		
+
 		if ($incoming['textile_body'] == LEAVE_TEXT_UNTOUCHED) {
-		
+
 			$incoming['Body_html'] = trim($incoming['Body']);
-			
+
 		}elseif ($incoming['textile_body'] == USE_TEXTILE){
-		
+
 			$incoming['Body_html'] = $textile->TextileThis($incoming['Body']);
 			$incoming['Title'] = $textile->TextileThis($incoming['Title'],'',1);
-			
+
 		}elseif ($incoming['textile_body'] == CONVERT_LINEBREAKS){
-			
+
 			$incoming['Body_html'] = nl2br(trim($incoming['Body']));
 		}
 
 		if ($incoming['textile_excerpt'] == LEAVE_TEXT_UNTOUCHED) {
-		
+
 			$incoming['Excerpt_html'] = trim($incoming['Excerpt']);
-			
+
 		}elseif ($incoming['textile_excerpt'] == USE_TEXTILE){
-		
+
 			$incoming['Excerpt_html'] = $textile->TextileThis($incoming['Excerpt']);
-			
+
 		}elseif ($incoming['textile_excerpt'] == CONVERT_LINEBREAKS){
-			
+
 			$incoming['Excerpt_html'] = nl2br(trim($incoming['Excerpt']));
 		}
-		
+
 		return $incoming;
 	}
 // -------------------------------------------------------------
-
 	function do_pings()
 	{
 		global $txpcfg, $prefs, $production_status;
@@ -974,7 +1174,7 @@ if (!empty($event) and $event == 'article') {
 		include_once txpath.'/lib/IXRClass.php';
 
 		callback_event('ping');
-		
+
 		if ($prefs['ping_textpattern_com']) {
 			$tx_client = new IXR_Client('http://textpattern.com/xmlrpc/');
 			$tx_client->query('ping.Textpattern', $prefs['sitename'], hu);
@@ -985,5 +1185,18 @@ if (!empty($event) and $event == 'article') {
 			$wl_client->query('weblogUpdates.ping', $prefs['sitename'], hu);
 		}
 	}
-
+// -------------------------------------------------------------
+	function article_save_pane_state()
+	{
+		global $event;
+		$panes = array('textile_help', 'advanced', 'recent', 'more');
+		$pane = gps('pane');
+		if (in_array($pane, $panes))
+		{
+			set_pref("pane_{$event}_{$pane}_visible", (gps('visible') == 'true' ? '1' : '0'), $event, PREF_HIDDEN, 'yesnoradio', 0, PREF_PRIVATE);
+			send_xml_response();
+		} else {
+			send_xml_response(array('http-status' => '400 Bad Request'));
+		}
+	}
 ?>
