@@ -13,8 +13,8 @@
 	"Mod File Upload" Copyright 2004 by Michael Manfre. All rights reserved.
 	Use of this mod denotes acceptance of the Textpattern license agreement
 
-$HeadURL: http://svn.textpattern.com/releases/4.0.6/source/textpattern/include/txp_file.php $
-$LastChangedRevision: 2530 $
+$HeadURL: https://textpattern.googlecode.com/svn/releases/4.2.0/source/textpattern/include/txp_file.php $
+$LastChangedRevision: 3200 $
 
 */
 
@@ -33,25 +33,25 @@ $LastChangedRevision: 2530 $
 	);
 
 	if ($event == 'file') {
-		require_privs('file');		
+		require_privs('file');
 
-		if(!$step or !in_array($step, array('file_change_max_size','file_change_pageby','file_db_add','file_delete','file_edit','file_insert','file_list','file_replace','file_save','file_reset_count','file_create'))){
+		if(!$step or !in_array($step, array('file_change_pageby','file_multi_edit','file_edit','file_insert','file_list','file_replace','file_save','file_reset_count','file_create'))){
 			file_list();
 		} else $step();
 	}
 
 // -------------------------------------------------------------
 
-	function file_list($message = '') 
+	function file_list($message = '')
 	{
-		global $txpcfg, $extensions, $file_base_path, $file_statuses;
+		global $file_base_path, $file_statuses, $file_list_pageby, $txp_user;
 
 		pagetop(gTxt('file'), $message);
 
-		extract($txpcfg);
-		extract(get_prefs());
-
 		extract(gpsa(array('page', 'sort', 'dir', 'crit', 'search_method')));
+		if ($sort === '') $sort = get_pref('file_sort_column', 'filename');
+		if ($dir === '') $dir = get_pref('file_sort_dir', 'asc');
+		$dir = ($dir == 'desc') ? 'desc' : 'asc';
 
 		if (!is_dir($file_base_path) or !is_writeable($file_base_path))
 		{
@@ -60,7 +60,7 @@ $LastChangedRevision: 2530 $
 			, ' id="warning"');
 		}
 
-		else
+		elseif (has_privs('file.edit.own'))
 		{
 			$existing_files = get_filenames();
 
@@ -79,8 +79,6 @@ $LastChangedRevision: 2530 $
 			echo file_upload_form(gTxt('upload_file'), 'upload', 'file_insert');
 		}
 
-		$dir = ($dir == 'desc') ? 'desc' : 'asc';
-
 		switch ($sort)
 		{
 			case 'id':
@@ -99,12 +97,19 @@ $LastChangedRevision: 2530 $
 				$sort_sql = 'downloads '.$dir.', filename desc';
 			break;
 
+			case 'author':
+				$sort_sql = 'author '.$dir.', id asc';
+			break;
+
 			default:
 				$sort = 'filename';
 				$sort_sql = 'filename '.$dir;
 			break;
 		}
 
+		set_pref('file_sort_column', $sort, 'file', 2, '', 0, PREF_PRIVATE);
+		set_pref('file_sort_dir', $dir, 'file', 2, '', 0, PREF_PRIVATE);
+
 		$switch_dir = ($dir == 'desc') ? 'asc' : 'desc';
 
 		$criteria = 1;
@@ -114,10 +119,11 @@ $LastChangedRevision: 2530 $
 			$crit_escaped = doSlash($crit);
 
 			$critsql = array(
-				'id'			    => "id = '$crit_escaped'",
+				'id'		  => "ID in ('" .join("','", do_list($crit_escaped)). "')",
 				'filename'    => "filename like '%$crit_escaped%'",
 				'description' => "description like '%$crit_escaped%'",
-				'category'    => "category like '%$crit_escaped%'"
+				'category'    => "category like '%$crit_escaped%'",
+				'author'	=> "author like '%$crit_escaped%'"
 			);
 
 			if (array_key_exists($search_method, $critsql))
@@ -146,18 +152,18 @@ $LastChangedRevision: 2530 $
 			if ($criteria != 1)
 			{
 				echo n.file_search_form($crit, $search_method).
-					n.graf(gTxt('no_results_found'), ' style="text-align: center;"');
+					n.graf(gTxt('no_results_found'), ' class="indicator"');
 			}
 
 			else
 			{
-				echo n.graf(gTxt('no_files_recorded'), ' style="text-align: center;"');
+				echo n.graf(gTxt('no_files_recorded'), ' class="indicator"');
 			}
 
 			return;
 		}
 
-		$limit = max(@$file_list_pageby, 15);
+		$limit = max($file_list_pageby, 15);
 
 		list($page, $offset, $numPages) = pager($total, $limit, $page);
 
@@ -167,7 +173,11 @@ $LastChangedRevision: 2530 $
 
 		if ($rs)
 		{
-			echo startTable('list').
+			$show_authors = !has_single_author('txp_file');
+
+			echo '<form name="longform" method="post" action="index.php" onsubmit="return verify(\''.gTxt('are_you_sure').'\')">'.
+
+			startTable('list').
 
 				tr(
 					column_head('ID', 'id', 'file', true, $switch_dir, $crit, $search_method, ('id' == $sort) ? $dir : '').
@@ -180,6 +190,7 @@ $LastChangedRevision: 2530 $
 					hCell(gTxt('status')).
 					hCell(gTxt('condition')).
 					column_head('downloads', 'downloads', 'file', true, $switch_dir, $crit, $search_method, ('downloads' == $sort) ? $dir : '').
+					($show_authors ? column_head('author', 'author', 'file', true, $switch_dir, $crit, $search_method, ('author' == $sort) ? $dir : '') : '').
 					hCell()
 				);
 
@@ -205,19 +216,21 @@ $LastChangedRevision: 2530 $
 				$condition .= ($file_exists) ? gTxt('file_status_ok') : gTxt('file_status_missing');
 				$condition .= '</span>';
 
+				$can_edit = has_privs('file.edit') || ($author == $txp_user && has_privs('file.edit.own'));
+
 				echo tr(
 
 					n.td($id).
 
 					td(
 						'<ul>'.
-						'<li>'.href(gTxt('edit'), $edit_url).'</li>'.
+						($can_edit ? '<li>'.href(gTxt('edit'), $edit_url).'</li>' : '').
 						$download_link.
 						'</ul>'
 					, 65).
 
 					td(
-						href(htmlspecialchars($filename), $edit_url)
+						($can_edit ? href(htmlspecialchars($filename), $edit_url) : htmlspecialchars($filename))
 					, 125).
 
 					td(htmlspecialchars($description), 150).
@@ -237,7 +250,7 @@ $LastChangedRevision: 2530 $
 						n.'</ul>'
 					, 75).
 
-					td($file_statuses[$status], 45).
+					td(in_array($status, array_keys($file_statuses)) ? $file_statuses[$status] : '<span class="not-ok">'.gTxt('none').'</span>', 45).
 
 					td($condition, 45).
 
@@ -245,41 +258,145 @@ $LastChangedRevision: 2530 $
 						($downloads == '0' ? gTxt('none') : $downloads)
 					, 25).
 
-					td(
-						dLink('file', 'file_delete', 'id', $id, '', '', '', false, array($page, $sort, $dir, $crit, $search_method))
+					($show_authors ? td(
+						'<span title="'.htmlspecialchars(get_author_name($author)).'">'.htmlspecialchars($author).'</span>'
+					) : '').
+
+					td($can_edit ? fInput('checkbox', 'selected[]', $id) : '&nbsp;'
 					, 10)
 				);
 			}
 
-			echo endTable().
+			echo tr(
+				tda(
+					select_buttons().
+					file_multiedit_form($page, $sort, $dir, $crit, $search_method)
+				,' colspan="'.($show_authors ? '11' : '10').'" style="text-align: right; border: none;"')
+			).
 
-			nav_form('file', $page, $numPages, $sort, $dir, $crit, $search_method).
+			endTable().
+			'</form>'.
+
+			nav_form('file', $page, $numPages, $sort, $dir, $crit, $search_method, $total, $limit).
 
 			pageby_form('file', $file_list_pageby);
 		}
 	}
-	
+
 // -------------------------------------------------------------
 
 	function file_search_form($crit, $method)
 	{
 		$methods =	array(
-			'id'					=> gTxt('ID'),
+			'id'			=> gTxt('ID'),
 			'filename'		=> gTxt('file_name'),
-			'description' => gTxt('description'),
-			'category'		=> gTxt('file_category')
+			'description' 	=> gTxt('description'),
+			'category'		=> gTxt('file_category'),
+			'author'		=> gTxt('author')
 		);
 
 		return search_form('file', 'file_list', $crit, $methods, $method, 'filename');
 	}
 
+// -------------------------------------------------------------
+
+	function file_multiedit_form($page, $sort, $dir, $crit, $search_method)
+	{
+		$methods = array(
+			'changecategory'  => gTxt('changecategory'),
+			'changeauthor' => gTxt('changeauthor'),
+			'delete'          => gTxt('delete'),
+		);
+
+		if (has_single_author('txp_file'))
+		{
+			unset($methods['changeauthor']);
+		}
+
+		if (!has_privs('file.delete.own') && !has_privs('file.delete'))
+		{
+			unset($methods['delete']);
+		}
+
+		return event_multiedit_form('file', $methods, $page, $sort, $dir, $crit, $search_method);
+	}
+
+// -------------------------------------------------------------
+
+	function file_multi_edit()
+	{
+		global $txp_user;
+		$selected = ps('selected');
+
+		if (!$selected or !is_array($selected))
+		{
+			return file_list();
+		}
+
+		$selected = array_map('assert_int', $selected);
+		$method   = ps('edit_method');
+		$changed  = array();
+
+		switch ($method)
+		{
+			case 'delete';
+				return file_delete($selected);
+				break;
+
+			case 'changecategory':
+				$key = 'category';
+				$val = ps('category');
+				break;
+
+			case 'changeauthor';
+				$key = 'author';
+				$val = ps('author');
+				break;
+
+			default:
+				$key = '';
+				$val = '';
+				break;
+		}
+
+		if (!has_privs('file.edit'))
+		{
+			if (has_privs('file.edit.own'))
+			{
+				$selected = safe_column('id', 'txp_file', 'id IN ('.join(',', $selected).') AND author=\''.doSlash($txp_user).'\'');
+			}
+			else
+			{
+				$selected = array();
+			}
+		}
+
+		if ($selected and $key)
+		{
+			foreach ($selected as $id)
+			{
+				if (safe_update('txp_file', "$key = '".doSlash($val)."'", "id = $id"))
+				{
+					$changed[] = $id;
+				}
+			}
+		}
+
+		if ($changed)
+		{
+			update_lastmod();
+
+			return file_list(gTxt('file_updated', array('{name}' => join(', ', $changed))));
+		}
+
+		return file_list();
+	}
+
 // -------------------------------------------------------------
 
 	function file_edit($message = '', $id = '')
 	{
-		global $txpcfg, $file_base_path, $levels, $file_statuses;
-
-		pagetop('file', $message);
+		global $file_base_path, $levels, $file_statuses, $txp_user;
 
 		extract(gpsa(array('name', 'category', 'permissions', 'description', 'sort', 'dir', 'page', 'crit', 'search_method', 'publish_now')));
 
@@ -297,7 +414,16 @@ $LastChangedRevision: 2530 $
 		{
 			extract($rs);
 
+			if (!has_privs('file.edit') && !($author == $txp_user && has_privs('file.edit.own')))
+			{
+				file_list(gTxt('restricted_area'));
+				return;
+			}
+
+			pagetop(gTxt('file'), $message);
+
 			if ($permissions=='') $permissions='-1';
+			if (!has_privs('file.publish') && $status >= 4) $status = 3;
 
 			$file_exists = file_exists(build_file_path($file_base_path,$filename));
 			$replace = ($file_exists) ? tr(td(file_upload_form(gTxt('replace_file'),'upload','file_replace',$id))) : '';
@@ -311,7 +437,7 @@ $LastChangedRevision: 2530 $
 			$condition .= '</span>';
 
 			$downloadlink = ($file_exists)?make_download_link($id, htmlspecialchars($filename),$filename):htmlspecialchars($filename);
-			
+
 			$created =
 					n.graf(checkbox('publish_now', '1', $publish_now, '', 'publish_now').'<label for="publish_now">'.gTxt('set_to_now').'</label>').
 
@@ -341,6 +467,7 @@ $LastChangedRevision: 2530 $
 									graf(gTxt('description').br.text_area('description','100','400',$description)) .
 									fieldset(radio_list('status', $file_statuses, $status, 4), gTxt('status'), 'file-status').
 									fieldset($created, gTxt('timestamp'), 'file-created').
+									pluggable_ui('file_ui', 'extend_detail_form', '', $rs).
 									graf(fInput('submit','',gTxt('save'))) .
 
 									eInput('file') .
@@ -358,7 +485,7 @@ $LastChangedRevision: 2530 $
 							)
 						);
 			} else {
-			
+
 				$form =	tr(
 							tda(
 								hed(gTxt('file_relink'),3).
@@ -366,6 +493,7 @@ $LastChangedRevision: 2530 $
 								form(
 									graf(gTxt('existing_file').' '.
 									selectInput('filename',$existing_files,"",1).
+									pluggable_ui('file_ui', 'extend_detail_form', '', $rs).
 									fInput('submit','',gTxt('Save'),'smallerbox').
 
 									eInput('file').
@@ -389,7 +517,7 @@ $LastChangedRevision: 2530 $
 							)
 						);
 			}
-			echo startTable('list'),
+			echo startTable('list', '', 'edit-pane'),
 			tr(
 				td(
 					graf(gTxt('file_status').br.$condition) .
@@ -404,8 +532,9 @@ $LastChangedRevision: 2530 $
 	}
 
 // -------------------------------------------------------------
-	function file_db_add($filename,$category,$permissions,$description,$size)
+	function file_db_add($filename, $category, $permissions, $description, $size)
 	{
+		global $txp_user;
 		$rs = safe_insert("txp_file",
 			"filename = '$filename',
 			 category = '$category',
@@ -413,29 +542,36 @@ $LastChangedRevision: 2530 $
 			 description = '$description',
 			 size = '$size',
 			 created = now(),
-			 modified = now()
+			 modified = now(),
+			 author = '$txp_user'
 		");
-		
+
 		if ($rs) {
 			$GLOBALS['ID'] = mysql_insert_id( );
 			return $GLOBALS['ID'];
 		}
 
 		return false;
-	}	
-	
+	}
+
 // -------------------------------------------------------------
-	function file_create() 
-	{	
-		global $txpcfg,$extensions,$txp_user,$file_base_path;
-		extract($txpcfg);
+	function file_create()
+	{
+		global $txp_user,$file_base_path;
+
+		if (!has_privs('file.edit.own'))
+		{
+			file_list(gTxt('restricted_area'));
+			return;
+		}
+
 		extract(doSlash(gpsa(array('filename','category','permissions','description'))));
 
 		$size = filesize(build_file_path($file_base_path,$filename));
 		$id = file_db_add($filename,$category,$permissions,$description, $size);
-		
+
 		if($id === false){
-			file_list(gTxt('file_upload_failed').' (db_add)');
+			file_list(array(gTxt('file_upload_failed').' (db_add)', E_ERROR));
 		} else {
 			$newpath = build_file_path($file_base_path,trim($filename));
 
@@ -449,10 +585,16 @@ $LastChangedRevision: 2530 $
 	}
 
 // -------------------------------------------------------------
-	function file_insert() 
-	{	
-		global $txpcfg,$extensions,$txp_user,$file_base_path,$file_max_upload_size;
-		extract($txpcfg);
+	function file_insert()
+	{
+		global $txp_user,$file_base_path,$file_max_upload_size;
+
+		if (!has_privs('file.edit.own'))
+		{
+			file_list(gTxt('restricted_area'));
+			return;
+		}
+
 		extract(doSlash(gpsa(array('category','permissions','description'))));
 
 		$name = file_get_uploaded_name();
@@ -460,38 +602,40 @@ $LastChangedRevision: 2530 $
 
 		if ($file === false) {
 			// could not get uploaded file
-			file_list(gTxt('file_upload_failed') ." $name - ".upload_get_errormsg($_FILES['thefile']['error']));
+			file_list(array(gTxt('file_upload_failed') ." $name - ".upload_get_errormsg($_FILES['thefile']['error']), E_ERROR));
 			return;
 		}
 
 		$size = filesize($file);
 		if ($file_max_upload_size < $size) {
 			unlink($file);
-			file_list(gTxt('file_upload_failed') ." $name - ".upload_get_errormsg(UPLOAD_ERR_FORM_SIZE));
+			file_list(array(gTxt('file_upload_failed') ." $name - ".upload_get_errormsg(UPLOAD_ERR_FORM_SIZE), E_ERROR));
 			return;
 		}
 
-		if (!is_file(build_file_path($file_base_path,$name))) {
+		$newname = sanitizeForFile($name);
+		$newpath = build_file_path($file_base_path, $newname);
+
+		if (!is_file($newname)) {
+
+			$id = file_db_add($newname,$category,$permissions,$description,$size);
 
-			$id = file_db_add($name,$category,$permissions,$description,$size);
-			
 			if(!$id){
-				file_list(gTxt('file_upload_failed').' (db_add)');
+				file_list(array(gTxt('file_upload_failed').' (db_add)', E_ERROR));
 			} else {
 
 				$id = assert_int($id);
-				$newpath = build_file_path($file_base_path,trim($name));
-				
+
 				if(!shift_uploaded_file($file, $newpath)) {
 					safe_delete("txp_file","id = $id");
 					safe_alter("txp_file", "auto_increment=$id");
 					if ( isset( $GLOBALS['ID'])) unset( $GLOBALS['ID']);
-					file_list($newpath.' '.gTxt('upload_dir_perms'));
+					file_list(array($newpath.' '.gTxt('upload_dir_perms'), E_ERROR));
 					// clean up file
 				} else {
 					file_set_perm($newpath);
 
-					$message = gTxt('file_uploaded', array('{name}' => htmlspecialchars($name)));
+					$message = gTxt('file_uploaded', array('{name}' => htmlspecialchars($newname)));
 
 					file_edit($message, $id);
 				}
@@ -500,7 +644,7 @@ $LastChangedRevision: 2530 $
 
 		else
 		{
-			$message = gTxt('file_already_exists', array('{name}' => $name));
+			$message = gTxt('file_already_exists', array('{name}' => $newname));
 
 			file_list($message);
 		}
@@ -508,20 +652,26 @@ $LastChangedRevision: 2530 $
 
 // -------------------------------------------------------------
 	function file_replace()
-	{	
-		global $txpcfg,$extensions,$txp_user,$file_base_path;
-		extract($txpcfg);
+	{
+		global $txp_user,$file_base_path;
+
 		$id = assert_int(gps('id'));
 
-		$rs = safe_row('filename','txp_file',"id = $id");
-		
+		$rs = safe_row('filename, author','txp_file',"id = $id");
+
 		if (!$rs) {
-			file_list(messenger(gTxt('invalid_id'),$id,''));
+			file_list(messenger(array(gTxt('invalid_id'), E_ERROR),$id,''));
 			return;
 		}
 
 		extract($rs);
-		
+
+		if (!has_privs('file.edit') && !($author == $txp_user && has_privs('file.edit.own')))
+		{
+			file_edit(gTxt('restricted_area'));
+			return;
+		}
+
 		$file = file_get_uploaded();
 		$name = file_get_uploaded_name();
 
@@ -546,9 +696,9 @@ $LastChangedRevision: 2530 $
 				file_list($newpath.sp.gTxt('upload_dir_perms'));
 				// rename tmp back
 				rename($newpath.'.tmp',$newpath);
-				
+
 				// remove tmp upload
-				unlink($file);				
+				unlink($file);
 			} else {
 				file_set_perm($newpath);
 				if ($size = filesize($newpath))
@@ -566,10 +716,12 @@ $LastChangedRevision: 2530 $
 
 
 // -------------------------------------------------------------
-	function file_reset_count() 
+	function file_reset_count()
 	{
+		// TODO: accompanying user interface
+
 		extract(doSlash(gpsa(array('id','filename','category','description'))));
-		
+
 		if ($id) {
 			$id = assert_int($id);
 			if (safe_update('txp_file','downloads = 0',"id = $id")) {
@@ -577,14 +729,14 @@ $LastChangedRevision: 2530 $
 			}
 		} else {
 			file_list(gTxt('reset_file_count_failure'));
-		}		
+		}
 	}
 
 // -------------------------------------------------------------
 
-	function file_save() 
+	function file_save()
 	{
-		global $file_base_path;
+		global $file_base_path, $txp_user;
 
 		extract(doSlash(gpsa(array('id', 'filename', 'category', 'description', 'status', 'publish_now', 'year', 'month', 'day', 'hour', 'minute', 'second'))));
 
@@ -598,8 +750,14 @@ $LastChangedRevision: 2530 $
 
 		$perms = doSlash($permissions);
 
-		$old_filename = fetch('filename','txp_file','id',$id);
-		
+		$rs = safe_row('filename, author', 'txp_file', "id=$id");
+		if (!has_privs('file.edit') && !($rs['author'] == $txp_user && has_privs('file.edit.own')))
+		{
+			file_edit(gTxt('restricted_area'));
+			return;
+		}
+
+		$old_filename = $rs['filename'];
 		if ($old_filename != false && strcmp($old_filename, $filename) != 0)
 		{
 			$old_path = build_file_path($file_base_path,$old_filename);
@@ -617,7 +775,7 @@ $LastChangedRevision: 2530 $
 				file_set_perm($new_path);
 			}
 		}
-		
+
 		$created_ts = @safe_strtotime($year.'-'.$month.'-'.$day.' '.$hour.':'.$minute.':'.$second);
 		if ($publish_now)
 			$created = 'now()';
@@ -634,7 +792,8 @@ $LastChangedRevision: 2530 $
 			description = '$description',
 			status = '$status',
 			size = '$size',
-			modified = now()"
+			modified = now(),
+			author = '$txp_user'"
 			.($created ? ", created = $created" : '')
 		, "id = $id");
 
@@ -663,47 +822,68 @@ $LastChangedRevision: 2530 $
 
 // -------------------------------------------------------------
 
-	function file_delete()
+	function file_delete($ids = array())
 	{
-		global $txpcfg, $file_base_path;
+		global $file_base_path, $txp_user;
 
-		extract($txpcfg);
+		$ids  = $ids ? array_map('assert_int', $ids) : array(assert_int(ps('id')));
+		$message = '';
 
-		$id = assert_int(ps('id'));
-
-		$rs = safe_row('*', 'txp_file', "id = $id");
-
-		if ($rs)
+		if (!has_privs('file.delete'))
 		{
-			extract($rs);
-
-			$filepath = build_file_path($file_base_path, $filename);
-
-			$rsd = safe_delete('txp_file', "id = $id");
-			$ul = false;
-
-			if ($rsd && is_file($filepath))
+			if (has_privs('file.delete.own'))
 			{
-				$ul = unlink($filepath);
+				$ids = safe_column('id', 'txp_file', 'id IN ('.join(',', $ids).') AND author=\''.doSlash($txp_user).'\'' );
 			}
-
-			if ($rsd && $ul)
-			{
-				$message = gTxt('file_deleted', array('{name}' => $filename));
-
-				return file_list($message);
-			}
-
 			else
 			{
-				file_list(messenger(gTxt('file_delete_failed'), $filename, ''));
+				$ids = array();
 			}
 		}
 
-		else
+		if (!empty($ids))
 		{
-			file_list(messenger(gTxt('file_not_found'), $filename, ''));
+			$fail = array();
+
+			$rs = safe_rows_start('id, filename', 'txp_file', 'id IN ('.join(',', $ids).')');
+
+			if ($rs)
+			{
+				while ($a = nextRow($rs))
+				{
+					extract($a);
+
+					$filepath = build_file_path($file_base_path, $filename);
+
+					$rsd = safe_delete('txp_file', "id = $id");
+					$ul  = false;
+
+					if ($rsd && is_file($filepath))
+					{
+						$ul = unlink($filepath);
+					}
+
+					if (!$rsd or !$ul)
+					{
+						$fail[] = $id;
+					}
+				}
+				if ($fail)
+				{
+					$message = messenger(gTxt('file_delete_failed'), join(', ', $fail), '');
+				}
+				else
+				{
+					update_lastmod();
+					$message = gTxt('file_deleted', array('{name}' => join(', ', $ids)));
+				}
+			}
+			else
+			{
+				$message = messenger(gTxt('file_not_found'), join(', ', $ids), '');
+			}
 		}
+		file_list($message);
 	}
 
 // -------------------------------------------------------------
@@ -715,40 +895,33 @@ $LastChangedRevision: 2530 $
 // -------------------------------------------------------------
 	function file_get_uploaded()
 	{
-		return get_uploaded_file($_FILES['thefile']['tmp_name']);		
+		return get_uploaded_file($_FILES['thefile']['tmp_name']);
 	}
-	
+
 // -------------------------------------------------------------
 	function file_set_perm($file)
 	{
 		return @chmod($file,0644);
-	}	
+	}
 
 // -------------------------------------------------------------
 	function file_upload_form($label,$pophelp,$step,$id='')
 	{
 		global $file_max_upload_size;
-		
+
 		if (!$file_max_upload_size || intval($file_max_upload_size)==0) $file_max_upload_size = 2*(1024*1024);
-		
+
 		$max_file_size = (intval($file_max_upload_size) == 0) ? '': intval($file_max_upload_size);
-			
+
 		return upload_form($label, $pophelp, $step, 'file', $id, $max_file_size);
 	}
-	
+
 // -------------------------------------------------------------
-	function file_change_pageby() 
+	function file_change_pageby()
 	{
 		event_change_pageby('file');
 		file_list();
 	}
-	
-// -------------------------------------------------------------
-	function file_change_max_size() 
-	{
-		// DEPRECATED function; removed old code
-		file_list();
-	}
 
 // -------------------------------------------------------------
 
@@ -758,30 +931,19 @@ $LastChangedRevision: 2530 $
 		$url = filedownloadurl($id, $filename);
 		return '<a href="'.$url.'">'.$label.'</a>';
 	}
-	
+
 // -------------------------------------------------------------
 	function get_filenames()
 	{
 		global $file_base_path;
-		
+
 		$dirlist = array();
 
 		if (!is_dir($file_base_path))
-			return $dirlist;		
-		
+			return $dirlist;
+
 		if (chdir($file_base_path)) {
-			if (function_exists('glob'))
-				$g_array = glob("*.*");
-			else {
-				$dh = opendir($file_base_path);
-				$g_array = array();
-				while (false !== ($filename = readdir($dh))) {
-					$g_array[] = $filename;
-				}
-				closedir($dh);
-				
-			}
-			
+			$g_array = glob("*.*");
 			if ($g_array) {
 				foreach ($g_array as $filename) {
 					if (is_file($filename)) {
@@ -799,8 +961,8 @@ $LastChangedRevision: 2530 $
 				$files[$a['filename']] = $a['filename'];
 			}
 		}
-		
+
 		return array_diff($dirlist,$files);
 	}
-	
+
 ?>
