@@ -7,10 +7,10 @@
 	www.textpattern.com
 	All rights reserved
 
-	Use of this software indicates acceptance of the Textpattern license agreement 
+	Use of this software indicates acceptance of the Textpattern license agreement
 
-$HeadURL: http://svn.textpattern.com/releases/4.0.6/source/textpattern/include/txp_image.php $
-$LastChangedRevision: 2668 $
+$HeadURL: https://textpattern.googlecode.com/svn/releases/4.2.0/source/textpattern/include/txp_image.php $
+$LastChangedRevision: 3267 $
 
 */
 
@@ -21,27 +21,34 @@ $LastChangedRevision: 2668 $
 	define("IMPATH",$path_to_site.DS.$img_dir.DS);
 	include txpath.'/lib/class.thumb.php';
 
-	if ($event == 'image') {	
-		require_privs('image');		
+	if ($event == 'image')
+	{
+		require_privs('image');
 
-		if(!$step or !in_array($step, array('image_list','image_edit','image_insert','image_delete','image_replace','image_save','thumbnail_insert','image_change_pageby','thumbnail_create','thumbnail_delete'
-		))){
+		if(!$step or !in_array($step, array('image_list','image_edit','image_insert','image_replace','image_save','thumbnail_insert','image_change_pageby','thumbnail_create','thumbnail_delete','image_multi_edit')))
+		{
 			image_list();
-		} else $step();
+		}
+		else
+		{
+			$step();
+		}
 	}
 
 // -------------------------------------------------------------
 
 	function image_list($message = '')
 	{
-		global $txpcfg, $extensions, $img_dir, $file_max_upload_size;
+		global $txpcfg, $extensions, $img_dir, $file_max_upload_size, $image_list_pageby, $txp_user;
 
 		pagetop(gTxt('images'), $message);
 
 		extract($txpcfg);
-		extract(get_prefs());
 
 		extract(gpsa(array('page', 'sort', 'dir', 'crit', 'search_method')));
+		if ($sort === '') $sort = get_pref('image_sort_column', 'id');
+		if ($dir === '') $dir = get_pref('image_sort_dir', 'desc');
+		$dir = ($dir == 'asc') ? 'asc' : 'desc';
 
 		if (!is_dir(IMPATH) or !is_writeable(IMPATH))
 		{
@@ -50,13 +57,11 @@ $LastChangedRevision: 2668 $
 			,' id="warning"');
 		}
 
-		else
+		elseif (has_privs('image.edit.own'))
 		{
 			echo upload_form(gTxt('upload_image'), 'upload', 'image_insert', 'image', '', $file_max_upload_size);
 		}
 
-		$dir = ($dir == 'asc') ? 'asc' : 'desc';
-
 		switch ($sort)
 		{
 			case 'name':
@@ -85,6 +90,9 @@ $LastChangedRevision: 2668 $
 			break;
 		}
 
+		set_pref('image_sort_column', $sort, 'image', 2, '', 0, PREF_PRIVATE);
+		set_pref('image_sort_dir', $dir, 'image', 2, '', 0, PREF_PRIVATE);
+
 		$switch_dir = ($dir == 'desc') ? 'asc' : 'desc';
 
 		$criteria = 1;
@@ -94,10 +102,12 @@ $LastChangedRevision: 2668 $
 			$crit_escaped = doSlash($crit);
 
 			$critsql = array(
-				'id'			 => "id = '$crit_escaped'",
-				'name'		 => "name like '%$crit_escaped%'",
-				'category' => "category like '%$crit_escaped%'",
-				'author'	 => "author like '%$crit_escaped%'"
+				'id'		=> "ID in ('" .join("','", do_list($crit_escaped)). "')",
+				'name'		=> "name like '%$crit_escaped%'",
+				'category' 	=> "category like '%$crit_escaped%'",
+				'author'	=> "author like '%$crit_escaped%'",
+				'alt'		=> "alt like '%$crit_escaped%'",
+				'caption'	=> "caption like '%$crit_escaped%'"
 			);
 
 			if (array_key_exists($search_method, $critsql))
@@ -125,18 +135,18 @@ $LastChangedRevision: 2668 $
 			if ($criteria != 1)
 			{
 				echo n.image_search_form($crit, $search_method).
-					n.graf(gTxt('no_results_found'), ' style="text-align: center;"');
+					n.graf(gTxt('no_results_found'), ' class="indicator"');
 			}
 
 			else
 			{
-				echo n.graf(gTxt('no_images_recorded'), ' style="text-align: center;"');
+				echo n.graf(gTxt('no_images_recorded'), ' class="indicator"');
 			}
 
 			return;
 		}
 
-		$limit = max(@$image_list_pageby, 15);
+		$limit = max($image_list_pageby, 15);
 
 		list($page, $offset, $numPages) = pager($total, $limit, $page);
 
@@ -148,7 +158,11 @@ $LastChangedRevision: 2668 $
 
 		if ($rs)
 		{
-			echo n.n.startTable('list').
+			$show_authors = !has_single_author('txp_image');
+
+			echo n.n.'<form name="longform" method="post" action="index.php" onsubmit="return verify(\''.gTxt('are_you_sure').'\')">'.
+
+			n.n.startTable('list').
 				n.tr(
 					column_head('ID', 'id', 'image', true, $switch_dir, $crit, $search_method, ('id' == $sort) ? $dir : '').
 					hCell().
@@ -157,7 +171,7 @@ $LastChangedRevision: 2668 $
 					column_head('thumbnail', 'thumbnail', 'image', true, $switch_dir, $crit, $search_method, ('thumbnail' == $sort) ? $dir : '').
 					hCell(gTxt('tags')).
 					column_head('image_category', 'category', 'image', true, $switch_dir, $crit, $search_method, ('category' == $sort) ? $dir : '').
-					column_head('author', 'author', 'image', true, $switch_dir, $crit, $search_method, ('author' == $sort) ? $dir : '').
+					($show_authors ? column_head('author', 'author', 'image', true, $switch_dir, $crit, $search_method, ('author' == $sort) ? $dir : '') : '').
 					hCell()
 				);
 
@@ -172,7 +186,9 @@ $LastChangedRevision: 2668 $
 
 				if ($thumbnail) {
 					if ($ext != '.swf') {
-						$thumbnail = '<img src="'.hu.$img_dir.'/'.$id.'t'.$ext.'" alt="" />';
+						$thumbnail = '<img src="'.hu.$img_dir.'/'.$id.'t'.$ext."?$uDate".'" alt="" '.
+											"title='$id$ext ($w &#215; $h)'".
+											($thumb_w ? "width='$thumb_w' height='$thumb_h'" : ''). ' />';
 					} else {
 						$thumbnail = '';
 					}
@@ -192,6 +208,7 @@ $LastChangedRevision: 2668 $
 				}
 
 				$category = ($category) ? '<span title="'.htmlspecialchars(fetch_category_title($category, 'image')).'">'.$category.'</span>' : '';
+				$can_edit = has_privs('image.edit') || ($author == $txp_user && has_privs('image.edit.own'));
 
 				echo n.n.tr(
 
@@ -199,7 +216,7 @@ $LastChangedRevision: 2668 $
 
 					td(
 						n.'<ul>'.
-						n.t.'<li>'.href(gTxt('edit'), $edit_url).'</li>'.
+						($can_edit ? n.t.'<li>'.href(gTxt('edit'), $edit_url).'</li>' : '').
 						n.t.'<li><a href="'.hu.$img_dir.'/'.$id.$ext.'">'.gTxt('view').'</a></li>'.
 						n.'</ul>'
 					, 35).
@@ -209,29 +226,37 @@ $LastChangedRevision: 2668 $
 					, 75).
 
 					td(
-						href($name, $edit_url)
+						($can_edit ? href($name, $edit_url) : $name)
 					, 75).
 
 					td(
-						href($thumbnail, $edit_url)
+						($can_edit ? href($thumbnail, $edit_url) : $thumbnail)
 					, 80).
 
 					td($tagbuilder, 85).
 					td($category, 75).
 
-					td(
+					($show_authors ? td(
 						'<span title="'.htmlspecialchars(get_author_name($author)).'">'.htmlspecialchars($author).'</span>'
-					, 75).
+					, 75) : '').
 
 					td(
-						dLink('image', 'image_delete', 'id', $id, '', '', '', false, array($page, $sort, $dir, $crit, $search_method))
+						fInput('checkbox', 'selected[]', $id)
 					, 10)
 				);
 			}
 
-			echo endTable().
+			echo n.n.tr(
+				tda(
+					select_buttons().
+					image_multiedit_form($page, $sort, $dir, $crit, $search_method)
+				,' colspan="'.($show_authors ? '9' : '8').'" style="text-align: right; border: none;"')
+			).
 
-			nav_form('image', $page, $numPages, $sort, $dir, $crit, $search_method).
+			endTable().
+			'</form>'.
+
+			nav_form('image', $page, $numPages, $sort, $dir, $crit, $search_method, $total, $limit).
 
 			pageby_form('image', $image_list_pageby);
 		}
@@ -242,46 +267,151 @@ $LastChangedRevision: 2668 $
 	function image_search_form($crit, $method)
 	{
 		$methods =	array(
-			'id'       => gTxt('ID'),
-			'name'     => gTxt('name'),
-			'category' => gTxt('image_category'),
-			'author'	 => gTxt('author')
+			'id'       	=> gTxt('ID'),
+			'name'     	=> gTxt('name'),
+			'category' 	=> gTxt('image_category'),
+			'author'	=> gTxt('author'),
+			'alt'	 	=> gTxt('alt_text'),
+			'caption'	=> gTxt('caption')
 		);
 
 		return search_form('image', 'image_list', $crit, $methods, $method, 'name');
 	}
 
 // -------------------------------------------------------------
-	function image_edit($message='',$id='') 
+
+	function image_multiedit_form($page, $sort, $dir, $crit, $search_method)
 	{
+		$methods = array(
+			'changecategory'  => gTxt('changecategory'),
+			'changeauthor'    => gTxt('changeauthor'),
+			'delete'          => gTxt('delete'),
+		);
+
+		if (has_single_author('txp_image'))
+		{
+			unset($methods['changeauthor']);
+		}
+
+		if (!has_privs('image.delete.own') && !has_privs('image.delete'))
+		{
+			unset($methods['delete']);
+		}
+
+		return event_multiedit_form('image', $methods, $page, $sort, $dir, $crit, $search_method);
+	}
+
+// -------------------------------------------------------------
+
+	function image_multi_edit()
+	{
+		global $txp_user;
+
+		$selected = ps('selected');
+
+		if (!$selected or !is_array($selected))
+		{
+			return image_list();
+		}
+
+		$selected = array_map('assert_int', $selected);
+		$method   = ps('edit_method');
+		$changed  = array();
+
+		switch ($method)
+		{
+			case 'delete';
+				return image_delete($selected);
+				break;
+
+			case 'changecategory':
+				$key = 'category';
+				$val = ps('category');
+				break;
+
+			case 'changeauthor';
+				$key = 'author';
+				$val = ps('author');
+				break;
+
+			default:
+				$key = '';
+				$val = '';
+				break;
+		}
+
+		if (!has_privs('image.edit'))
+		{
+			if (has_privs('image.edit.own'))
+			{
+				$selected = safe_column('id', 'txp_image', 'id IN ('.join(',', $selected).') AND author=\''.doSlash($txp_user).'\'');
+			}
+			else
+			{
+				$selected = array();
+			}
+		}
+
+		if ($selected and $key)
+		{
+			foreach ($selected as $id)
+			{
+				if (safe_update('txp_image', "$key = '".doSlash($val)."'", "id = $id"))
+				{
+					$changed[] = $id;
+				}
+			}
+		}
+
+		if ($changed)
+		{
+			update_lastmod();
+
+			return image_list(gTxt('image_updated', array('{name}' => join(', ', $changed))));
+		}
+
+		return image_list();
+	}
+
+// -------------------------------------------------------------
+	function image_edit($message='',$id='')
+	{
+		global $txpcfg,$img_dir,$file_max_upload_size,$txp_user;
+
 		if (!$id) $id = gps('id');
 		$id = assert_int($id);
-		global $txpcfg,$img_dir,$file_max_upload_size;
 
-		pagetop(gTxt('edit_image'),$message);
-
-		extract(gpsa(array('page', 'sort', 'dir', 'crit', 'search_method')));
-
-		$categories = getTree("root", "image");
-		
-		$rs = safe_row("*", "txp_image", "id = $id");
+		$rs = safe_row("*, unix_timestamp(date) as uDate", "txp_image", "id = $id");
 
 		if ($rs) {
 			extract($rs);
 
+			if (!has_privs('image.edit') && !($author == $txp_user && has_privs('image.edit.own')))
+			{
+				image_list(gTxt('restricted_area'));
+				return;
+			}
+
+			pagetop(gTxt('edit_image'),$message);
+
+			extract(gpsa(array('page', 'sort', 'dir', 'crit', 'search_method')));
+
+			$categories = getTree("root", "image");
+
 			if ($ext != '.swf') {
-				$img = '<img src="'.hu.$img_dir.'/'.$id.$ext.'" height="'.$h.'" width="'.$w.'" alt="" title="'.$id.$ext.' ('.$w.' &#215; '.$h.')" />';
+				$img = '<img src="'.hu.$img_dir.'/'.$id.$ext."?$uDate".'" height="'.$h.'" width="'.$w.'" alt="" title="'.$id.$ext.' ('.$w.' &#215; '.$h.')" id="image-fullsize" />';
 			} else {
 				$img = '';
 			}
 
 			if ($thumbnail and ($ext != '.swf')) {
-				$thumb = '<img src="'.hu.$img_dir.'/'.$id.'t'.$ext.'" alt="" />';
+				$thumb = '<img src="'.hu.$img_dir.'/'.$id.'t'.$ext."?$uDate".'" alt="" '.
+							($thumb_w ? "width='$thumb_w' height='$thumb_h'" : ''). ' />';
 			} else {
 				$thumb = '';
 			}
 
-			echo startTable('list'),
+			echo startTable('list', '', 'edit-pane'),
 			tr(
 				td(
 					$img.br.
@@ -326,6 +456,8 @@ $LastChangedRevision: 2668 $
 						graf('<label for="caption">'.gTxt('caption').'</label>'.br.
 							text_area('caption', '100', '400', $caption, 'caption')).
 
+						pluggable_ui('image_ui', 'extend_detail_form', '', $rs).
+
 						n.graf(fInput('submit', '', gTxt('save'), 'publish')).
 						n.hInput('id', $id).
 						n.eInput('image').
@@ -344,11 +476,16 @@ $LastChangedRevision: 2668 $
 	}
 
 // -------------------------------------------------------------
-
 	function image_insert()
 	{
 		global $txpcfg, $extensions, $txp_user;
 
+		if (!has_privs('image.edit.own'))
+		{
+			image_list(gTxt('restricted_area'));
+			return;
+		}
+
 		extract($txpcfg);
 
 		$meta = gpsa(array('caption', 'alt', 'category'));
@@ -364,60 +501,72 @@ $LastChangedRevision: 2668 $
 
 		else
 		{
-			return image_list($img_result);
+			return image_list(array($img_result, E_ERROR));
 		}
 	}
 
 // -------------------------------------------------------------
-	function image_replace() 
-	{	
+	function image_replace()
+	{
 		global $txpcfg,$extensions,$txp_user;
 		extract($txpcfg);
-			
+
 		$id = assert_int(gps('id'));
 		$rs = safe_row("*", "txp_image", "id = $id");
-		
+
+		if (!has_privs('image.edit') && !($rs['author'] == $txp_user && has_privs('image.edit.own')))
+		{
+			image_list(gTxt('restricted_area'));
+			return;
+		}
+
 		if ($rs) {
 			$meta = array('category' => $rs['category'], 'caption' => $rs['caption'], 'alt' => $rs['alt']);
 		} else {
 			$meta = '';
-		} 
-		
+		}
+
 		$img_result = image_data($_FILES['thefile'], $meta, $id);
-		
+
 		if(is_array($img_result))
 		{
 			list($message, $id) = $img_result;
 			return image_edit($message, $id);
 		}else{
-			return image_list($img_result);
+			return image_list(array($img_result, E_ERROR));
 		}
 	}
 
 // -------------------------------------------------------------
-	function thumbnail_insert() 
+	function thumbnail_insert()
 	{
 		global $txpcfg,$extensions,$txp_user,$img_dir,$path_to_site;
 		extract($txpcfg);
 		$id = assert_int(gps('id'));
-		
+
+		$author = fetch('author', 'txp_image', 'id', $id);
+		if (!has_privs('image.edit') && !($author == $txp_user && has_privs('image.edit.own')))
+		{
+			image_list(gTxt('restricted_area'));
+			return;
+		}
+
 		$file = $_FILES['thefile']['tmp_name'];
 		$name = $_FILES['thefile']['name'];
 
 		$file = get_uploaded_file($file);
-		
-		list(,,$extension) = getimagesize($file);
-	
+
+		list($w, $h, $extension) = getimagesize($file);
+
 		if (($file !== false) && @$extensions[$extension]) {
 			$ext = $extensions[$extension];
+			$newpath = IMPATH.$id.'t'.$ext;
 
-				$newpath = IMPATH.$id.'t'.$ext;
-			
-			if(shift_uploaded_file($file, $newpath) == false) {
-				image_list($newpath.sp.gTxt('upload_dir_perms'));
+			if (shift_uploaded_file($file, $newpath) == false) {
+				image_list(array($newpath.sp.gTxt('upload_dir_perms'), E_ERROR));
 			} else {
-				chmod($newpath,0644);
-				safe_update("txp_image", "thumbnail = 1", "id = $id");
+				chmod($newpath, 0644);
+				safe_update("txp_image", "thumbnail = 1, thumb_w = $w, thumb_h = $h", "id = $id");
 
 				$message = gTxt('image_uploaded', array('{name}' => $name));
 				update_lastmod();
@@ -426,22 +575,33 @@ $LastChangedRevision: 2668 $
 			}
 		} else {
 			if ($file === false)
-				image_list(upload_get_errormsg($_FILES['thefile']['error']));
+				image_list(array(upload_get_errormsg($_FILES['thefile']['error']), E_ERROR));
 			else
-				image_list(gTxt('only_graphic_files_allowed'));
+				image_list(array(gTxt('only_graphic_files_allowed'), E_ERROR));
 		}
 	}
 
 
 // -------------------------------------------------------------
-	function image_save() 
+	function image_save()
 	{
-		extract(doSlash(gpsa(array('id','name','category','caption','alt'))));
+		global $txp_user;
+
+		extract(doSlash(gpsa(array('id','category','caption','alt'))));
+		$name = gps('name');
+		$safename = doSlash($name);
 		$id = assert_int($id);
-		
+
+		$author = fetch('author', 'txp_image', 'id', $id);
+		if (!has_privs('image.edit') && !($author == $txp_user && has_privs('image.edit.own')))
+		{
+			image_list(gTxt('restricted_area'));
+			return;
+		}
+
 		safe_update(
 			"txp_image",
-			"name     = '$name',
+			"name     = '$safename',
 			category = '$category',
 			alt      = '$alt',
 			caption  = '$caption'",
@@ -456,40 +616,69 @@ $LastChangedRevision: 2668 $
 
 // -------------------------------------------------------------
 
-	function image_delete() {
-		global $txpcfg;
+	function image_delete($ids = array())
+	{
+		global $txp_user;
 
-		extract($txpcfg);
+		$ids = $ids ? array_map('assert_int', $ids) : array(assert_int(ps('id')));
+		$message = '';
 
-		$id = assert_int(ps('id'));
-
-		$rs = safe_row('*', 'txp_image', "id = $id");
-
-		if ($rs) {
-			extract($rs);
-
-			$rsd = safe_delete('txp_image', "id = $id");
-
-			$ul = false;
-
-			if (is_file(IMPATH.$id.$ext)) {
-				$ul = unlink(IMPATH.$id.$ext);
+		if (!has_privs('image.delete'))
+		{
+			if (has_privs('image.delete.own'))
+			{
+				$ids = safe_column('id', 'txp_image', 'id IN ('.join(',', $ids).') AND author=\''.doSlash($txp_user).'\'' );
 			}
-
-			if (is_file(IMPATH.$id.'t'.$ext)) {
-				$ult = unlink(IMPATH.$id.'t'.$ext);
+			else
+			{
+				$ids = array();
 			}
-
-			if ($rsd && $ul) {
-				update_lastmod();
-
-				image_list(gTxt('image_deleted', array('{name}' => $name)));
-			} else {
-				image_list(gTxt('image_delete_failed', array('{name}' => $name)));
-			}
-		} else {
-			image_list();
 		}
+
+		if (!empty($ids))
+		{
+			$fail = array();
+
+			$rs   = safe_rows_start('id, ext', 'txp_image', 'id IN ('.join(',', $ids).')');
+
+			if ($rs)
+			{
+				while ($a = nextRow($rs))
+				{
+					extract($a);
+
+					$rsd = safe_delete('txp_image', "id = $id");
+
+					$ul  = false;
+
+					if (is_file(IMPATH.$id.$ext))
+					{
+						$ul = unlink(IMPATH.$id.$ext);
+					}
+
+					if (is_file(IMPATH.$id.'t'.$ext))
+					{
+						$ult = unlink(IMPATH.$id.'t'.$ext);
+					}
+
+					if (!$rsd or !$ul)
+					{
+						$fail[] = $id;
+					}
+				}
+
+				if ($fail)
+				{
+					$message = array(gTxt('image_delete_failed', array('{name}' => join(', ', $fail))), E_ERROR);
+				}
+				else
+				{
+					update_lastmod();
+					$message = gTxt('image_deleted', array('{name}' => join(', ', $ids)));
+				}
+			}
+		}
+		image_list($message);
 	}
 
 // -------------------------------------------------------------
@@ -501,7 +690,7 @@ $LastChangedRevision: 2668 $
 
 // -------------------------------------------------------------
 	function thumb_ui($id)
-	{		
+	{
 		global $prefs, $sort, $dir, $page, $search_method, $crit;
 		extract($prefs);
 		return
@@ -511,13 +700,13 @@ $LastChangedRevision: 2668 $
 					graf(gTxt('create_thumbnail')) .
 					startTable('','left','',1) .
 						tr(
-							fLabelCell(gTxt('thumb_width'), '', 'width') . 
+							fLabelCell(gTxt('thumb_width'), '', 'width') .
 							fInputCell('width', @$thumb_w, 1, 4, '', 'width').
 
-							fLabelCell(gTxt('thumb_height'), '', 'height') . 
+							fLabelCell(gTxt('thumb_height'), '', 'height') .
 							fInputCell('height', @$thumb_h, 1, 4, '', 'height').
 
-							fLabelCell(gTxt('keep_square_pixels'), '', 'crop') . 
+							fLabelCell(gTxt('keep_square_pixels'), '', 'crop') .
 							tda(checkbox('crop', 1, @$thumb_crop, '', 'crop'), ' class="noline"').
 
 							tda(
@@ -545,29 +734,41 @@ $LastChangedRevision: 2668 $
 
 	function thumbnail_create()
 	{
-		extract(doSlash(gpsa(array('id', 'width', 'height'))));
+		global $prefs, $txp_user;
 
-		// better checking of thumbnail dimensions
-		// don't try and use zeros
+		extract(doSlash(gpsa(array('id', 'width', 'height'))));
+		$id = assert_int($id);
+
+		$author = fetch('author', 'txp_image', 'id', $id);
+		if (!has_privs('image.edit') && !($author == $txp_user && has_privs('image.edit.own')))
+		{
+			image_list(gTxt('restricted_area'));
+			return;
+		}
 
 		$width = (int) $width;
 		$height = (int) $height;
 
-		if ($width == 0 && $height == 0) {
-			image_edit(messenger('invalid_width_or_height', "($width)/($height)", ''), $id);
-			return;
-		} else {
-			if ($width == 0) {
-				$width = '';
-			}
-
-			if ($height == 0) {
-				$height = '';
-			}
-		}
+		if ($width == 0) $width = '';
+		if ($height == 0) $height = '';
 
 		$crop = gps('crop');
 
+		$prefs['thumb_w'] = $width;
+		$prefs['thumb_h'] = $height;
+		$prefs['thumb_crop'] = $crop;
+
+		// hidden prefs
+		set_pref('thumb_w', $width, 'image', 2);
+		set_pref('thumb_h', $height, 'image', 2);
+		set_pref('thumb_crop', $crop, 'image', 2);
+
+		if ($width === '' && $height === '')
+		{
+			image_edit(array(gTxt('invalid_width_or_height'), E_ERROR), $id);
+			return;
+		}
+
 		$t = new txp_thumb( $id );
 		$t->crop = ($crop == '1');
 		$t->hint = '0';
@@ -577,17 +778,6 @@ $LastChangedRevision: 2668 $
 
 		if ($t->write())
 		{
-			global $prefs;
-
-			$prefs['thumb_w'] = $width;
-			$prefs['thumb_h'] = $height;
-			$prefs['thumb_crop'] = $crop;
-
-			// hidden prefs
-			set_pref('thumb_w', $width, 'image',	2);
-			set_pref('thumb_h', $height, 'image',	 2);
-			set_pref('thumb_crop', $crop, 'image',	2);
-
 			$message = gTxt('thumbnail_saved', array('{id}' => $id));
 			update_lastmod();
 
@@ -596,27 +786,37 @@ $LastChangedRevision: 2668 $
 
 		else
 		{
-			$message = gTxt('thumbnail_not_saved', array('{id}' => $id));
+			$message = array(gTxt('thumbnail_not_saved', array('{id}' => $id)), E_ERROR);
 
 			image_edit($message, $id);
 		}
 	}
 
 // -------------------------------------------------------------
-	function thumbnail_delete() 
+	function thumbnail_delete()
 	{
+		global $txp_user;
+
 		$id = assert_int(gps('id'));
+
+		$author = fetch('author', 'txp_image', 'id', $id);
+		if (!has_privs('image.edit') && !($author == $txp_user && has_privs('image.edit.own')))
+		{
+			image_list(gTxt('restricted_area'));
+			return;
+		}
+
 		$t = new txp_thumb($id);
 		if ($t->delete()) {
 			image_edit(gTxt('thumbnail_deleted'),$id);
 		} else {
-			image_edit(gTxt('thumbnail_delete_failed'),$id);
+			image_edit(array(gTxt('thumbnail_delete_failed'), E_ERROR),$id);
 		}
 	}
 
 // -------------------------------------------------------------
 // Refactoring attempt, allowing other - plugin - functions to
-// upload images without the need for writting duplicated code.
+// upload images without the need for writing duplicated code.
 
 	function image_data($file , $meta = '', $id = '', $uploaded = true)
 	{
@@ -646,7 +846,8 @@ $LastChangedRevision: 2668 $
 		{
 			$ext = $extensions[$extension];
 
-			$name = doSlash(substr($name, 0, strrpos($name, '.')).$ext);
+			$name = substr($name, 0, strrpos($name, '.')).$ext;
+			$safename = doSlash($name);
 
 			if ($meta == false)
 			{
@@ -656,7 +857,7 @@ $LastChangedRevision: 2668 $
 			extract(doSlash($meta));
 
 			$q ="
-				name = '$name',
+				name = '$safename',
 				ext = '$ext',
 				w = $w,
 				h = $h,
@@ -776,7 +977,7 @@ $LastChangedRevision: 2668 $
 
 				// check jpg support
 				case '.jpg':
-					return ($gd_info['JPG Support'] == 1) ? true : false;
+					return (!empty($gd_info['JPEG Support']) || !empty($gd_info['JPG Support'])) ? true : false;
 				break;
 
 				// unsupported format
