@@ -1,6 +1,6 @@
 <?php
 /*
-$HeadURL: http://svn.textpattern.com/releases/4.0.6/source/textpattern/include/txp_preview.php $
+$HeadURL: https://textpattern.googlecode.com/svn/releases/4.2.0/source/textpattern/include/txp_preview.php $
 $LastChangedRevision: 1238 $
 */
 if (!defined('txpinterface')) die('txpinterface is undefined.');
