@@ -9,8 +9,8 @@
 
 	Use of this software indicates acceptance of the Textpattern license agreement
 
-$HeadURL: http://svn.textpattern.com/releases/4.0.6/source/textpattern/include/txp_tag.php $
-$LastChangedRevision: 2774 $
+$HeadURL: https://textpattern.googlecode.com/svn/releases/4.2.0/source/textpattern/include/txp_tag.php $
+$LastChangedRevision: 3195 $
 
 */
 
@@ -26,8 +26,12 @@ if (!defined('txpinterface'))
 <head>
 	<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
 	<title>Txp &#8250; <?php echo gTxt('build'); ?></title>
-	<link rel="stylesheet" type="text/css" href="textpattern.css" />
-</head>
+	<script type="text/javascript" src="jquery.js"></script>
+	<?php echo script_js(
+		"var textpattern = {event: '$event', step: '$step'};"
+	); ?>
+	<?php echo $theme->html_head(); ?>
+	</head>
 <body id="tag-event">
 <?php
 
@@ -1435,6 +1439,100 @@ begin tag builder functions
 		return $out;
 	}
 
+// -------------------------------------------------------------
+
+	function tag_category()
+	{
+		global $step, $endform, $tag_name;
+
+		$atts = gpsa(array(
+			'class',
+			'link',
+			'name',
+			'this_section',
+			'title',
+			'type',
+			'url',
+			'wraptag'
+		));
+
+		extract($atts);
+
+		$out = form(
+			startTable('tagbuilder').
+
+			tr(
+				tdcs(
+					hed(gTxt('tag_'.$tag_name), 3)
+				, 2)
+			).
+
+			tagRow('name',
+				fInput('text', 'name', $name, 'edit', '', '', 25)).
+
+			tagRow('link_to_this_category',
+				yesno_pop('link', $link)).
+
+			tagRow('title',
+				yesno_pop('title', $title)).
+
+			tagRow('type',
+				type_pop('type', $type)).
+
+			tagRow('url_only',
+				yesno_pop('url', $url)).
+
+			tagRow('wraptag',
+				input_tag('wraptag', $wraptag)).
+
+			tagRow('class',
+				fInput('text', 'class', $class, 'edit', '', '', 25)).
+
+			$endform
+		);
+
+		if ($step == 'build')
+		{
+			$out .= tdb(tb($tag_name, $atts));
+		}
+
+		return $out;
+	}
+
+// -------------------------------------------------------------
+
+	function tag_if_category()
+	{
+		global $step, $endform, $tag_name;
+
+		$atts = gpsa(array(
+			'name'
+		));
+
+		extract($atts);
+
+		$out = form(
+			startTable('tagbuilder').
+
+			tr(
+				tdcs(
+					hed(gTxt('tag_'.$tag_name), 3)
+				, 2)
+			).
+
+			tagRow('name',
+				fInput('text', 'name', $name, 'edit', '', '', 25)).
+
+			$endform
+		);
+
+		if ($step == 'build')
+		{
+			$out .= tdb(tb($tag_name, $atts, gTxt('...')));
+		}
+
+		return $out;
+	}
 
 // -------------------------------------------------------------
 
@@ -1447,6 +1545,7 @@ begin tag builder functions
 			'link',
 			'name',
 			'title',
+			'url',
 			'wraptag'
 		));
 
@@ -1467,6 +1566,9 @@ begin tag builder functions
 			tagRow('link_to_this_section',
 				yesno_pop('link', $link)).
 
+			tagRow('url_only',
+				yesno_pop('url', $url)).
+
 			tagRow('wraptag',
 				input_tag('wraptag', $wraptag)).
 
@@ -1484,6 +1586,41 @@ begin tag builder functions
 		return $out;
 	}
 
+// -------------------------------------------------------------
+
+	function tag_if_section()
+	{
+		global $step, $endform, $tag_name;
+
+		$atts = gpsa(array(
+			'name'
+		));
+
+		extract($atts);
+
+		$out = form(
+			startTable('tagbuilder').
+
+			tr(
+				tdcs(
+					hed(gTxt('tag_'.$tag_name), 3)
+				, 2)
+			).
+
+			tagRow('name',
+				section_pop('name', $tag_name)).
+
+			$endform
+		);
+
+		if ($step == 'build')
+		{
+			$out .= tdb(tb($tag_name, $atts, gTxt('...')));
+		}
+
+		return $out;
+	}
+
 // -------------------------------------------------------------
 
 	function tag_author()
@@ -2803,8 +2940,9 @@ begin tag builder functions
 			'break',
 			'breakclass',
 			'class',
-			'id',
 			'form',
+			'limit',
+			'offset',
 			'sort',
 			'wraptag'
 		));
@@ -2820,15 +2958,18 @@ begin tag builder functions
 				, 2)
 			).
 
-			tagRow('id',
-				input_id($id)).
-
 			tagRow('form',
 				form_pop('form', 'comment', $form)).
 
 			tagRow('sort',
 				discuss_sort_pop($sort)).
 
+			tagRow('limit',
+				input_limit($limit)).
+
+			tagRow('offset',
+				input_offset($offset)).
+
 			tagRow('wraptag',
 				input_tag('wraptag', $wraptag)).
 
@@ -3295,9 +3436,9 @@ begin tag builder functions
 				default:
 
 					$atts = array(
-						'class'   => $class, 
-						'html_id' => $html_id, 
-						'id'      => $id, 
+						'class'   => $class,
+						'html_id' => $html_id,
+						'id'      => $id,
 						'style'   => $style,
 						'wraptag' => $wraptag
 					);
@@ -3592,7 +3733,7 @@ begin tag builder functions
 			$description = str_replace('&', '&#38;', htmlspecialchars($description));
 
 			$url = ($permlink_mode == 'messy') ?
-				hu.'index.php?s=file_download'.a.'id='.$id:
+				hu.'index.php?s=file_download'.($type == 'textile' ? '&' : a).'id='.$id:
 				hu.gTxt('file_download').'/'.$id.($filename ? '/'.$filename : '');
 
 			switch ($type)
