@@ -1,14 +1,16 @@
 <?php
 
-/* 
+/*
    IXR - The Inutio XML-RPC Library - (c) Incutio Ltd 2002
    Version 1.61 - Simon Willison, 11th July 2003 (htmlentities -> htmlspecialchars)
    Site:   http://scripts.incutio.com/xmlrpc/
    Manual: http://scripts.incutio.com/xmlrpc/manual.php
    Made available under the Artistic License: http://www.opensource.org/licenses/artistic-license.php
 
-$HeadURL: http://svn.textpattern.com/releases/4.0.6/source/textpattern/lib/IXRClass.php $
-$LastChangedRevision: 765 $
+   Contains Textpatternish amendments.
+
+$HeadURL: https://textpattern.googlecode.com/svn/releases/4.2.0/source/textpattern/lib/IXRClass.php $
+$LastChangedRevision: 2932 $
 */
 
 class IXR_Value {
@@ -51,7 +53,7 @@ class IXR_Value {
         }
         // If it is a normal PHP object convert it in to a struct
         if (is_object($this->data)) {
-            
+
             $this->data = get_object_vars($this->data);
             return 'struct';
         }
@@ -269,7 +271,7 @@ class IXR_Message {
                 $this->params[] = $value;
             }
         }
-    }       
+    }
 }
 
 
@@ -364,8 +366,8 @@ EOD;
     }
     function output($xml) {
         $xml = '<?xml version="1.0" encoding="utf-8" ?>'."\n".$xml;
-		if ( (@strpos($_SERVER["HTTP_ACCEPT_ENCODING"],'gzip') !== false) && extension_loaded('zlib') && 
-			ini_get("zlib.output_compression") == 0 && ini_get('output_handler') != 'ob_gzhandler' && !headers_sent()) 
+		if ( (@strpos($_SERVER["HTTP_ACCEPT_ENCODING"],'gzip') !== false) && extension_loaded('zlib') &&
+			ini_get("zlib.output_compression") == 0 && ini_get('output_handler') != 'ob_gzhandler' && !headers_sent())
 		{
 			$xml = gzencode($xml,7,FORCE_GZIP);
 			header("Content-Encoding: gzip");
@@ -396,7 +398,7 @@ EOD;
                 'specUrl' => 'http://www.xmlrpc.com/discuss/msgReader$1208',
                 'specVersion' => 1
             ),
-        );   
+        );
     }
     function getCapabilities($args) {
         return $this->capabilities;
@@ -506,7 +508,7 @@ class IXR_Client {
         $request .= "Content-Type: text/xml$r";
         $request .= "User-Agent: {$this->useragent}$r";
 		// Accept gzipped response if zlib and if php4.3+ (fgets turned binary safe)
-		if ( extension_loaded('zlib') && preg_match('#^(4\.[3-9])|([5-9])#',phpversion()) ) 
+		if ( extension_loaded('zlib') && preg_match('#^(4\.[3-9])|([5-9])#',phpversion()) )
 			$request .= "Accept-Encoding: gzip$r";
         $request .= "Content-length: {$length}$r$r";
         $request .= $xml;
@@ -517,7 +519,7 @@ class IXR_Client {
 		// This is to find out when the script unexpectedly dies due to fsockopen
 		ob_start(NULL, 2048);
 		echo "Trying to connect to an RPC Server...";
-        $fp = (is_callable('fsockopen')) ? fsockopen($this->server, $this->port, $errno, $errstr, 45) : false;
+        $fp = (!is_disabled('fsockopen')) ? fsockopen($this->server, $this->port, $errno, $errstr, 45) : false;
 		ob_end_clean();
         if (!$fp) {
             $this->error = new IXR_Error(-32300, 'transport error - could not open socket ('.$errstr.')');
@@ -545,13 +547,13 @@ class IXR_Client {
             if (!$gettingHeaders) {
 		        // We do a binary comparison of the first two bytes, see
 		        // rfc1952, to check wether the content is gzipped.
-				if ( ($contents=='') && (strncmp($line,"\x1F\x8B",2)===0)) 
+				if ( ($contents=='') && (strncmp($line,"\x1F\x8B",2)===0))
 					$is_gzipped = true;
                 $contents .= ($is_gzipped) ? $line : trim($line)."\n";
             }
         }
 		# if gzipped, strip the 10 byte header, and pass it to gzinflate (rfc1952)
-		if ($is_gzipped) 
+		if ($is_gzipped)
 		{
 			$contents = gzinflate(substr($contents, 10));
 			//simulate trim() for each line; don't know why, but it won't work otherwise
@@ -615,7 +617,7 @@ class IXR_Error {
       </struct>
     </value>
   </fault>
-</methodResponse> 
+</methodResponse>
 
 EOD;
         return $xml;
@@ -630,6 +632,7 @@ class IXR_Date {
     var $hour;
     var $minute;
     var $second;
+    var $tz;
     function IXR_Date($time) {
         // $time can be a PHP timestamp or an ISO one
         if (is_numeric($time)) {
@@ -648,14 +651,15 @@ class IXR_Date {
     }
     function parseIso($iso) {
         $this->year = substr($iso, 0, 4);
-        $this->month = substr($iso, 4, 2); 
+        $this->month = substr($iso, 4, 2);
         $this->day = substr($iso, 6, 2);
         $this->hour = substr($iso, 9, 2);
         $this->minute = substr($iso, 12, 2);
         $this->second = substr($iso, 15, 2);
+        $this->tz = substr($iso, 17);
     }
     function getIso() {
-        return $this->year.$this->month.$this->day.'T'.$this->hour.':'.$this->minute.':'.$this->second;
+        return $this->year.$this->month.$this->day.'T'.$this->hour.':'.$this->minute.':'.$this->second.$this->tz;
     }
     function getXml() {
         return '<dateTime.iso8601>'.$this->getIso().'</dateTime.iso8601>';
@@ -688,27 +692,27 @@ class IXR_IntrospectionServer extends IXR_Server {
             'specVersion' => 1
         );
         $this->addCallback(
-            'system.methodSignature', 
-            'this:methodSignature', 
-            array('array', 'string'), 
+            'system.methodSignature',
+            'this:methodSignature',
+            array('array', 'string'),
             'Returns an array describing the return type and required parameters of a method'
         );
         $this->addCallback(
-            'system.getCapabilities', 
-            'this:getCapabilities', 
-            array('struct'), 
+            'system.getCapabilities',
+            'this:getCapabilities',
+            array('struct'),
             'Returns a struct describing the XML-RPC specifications supported by this server'
         );
         $this->addCallback(
-            'system.listMethods', 
-            'this:listMethods', 
-            array('array'), 
+            'system.listMethods',
+            'this:listMethods',
+            array('array'),
             'Returns an array of available methods on this server'
         );
         $this->addCallback(
-            'system.methodHelp', 
-            'this:methodHelp', 
-            array('string', 'string'), 
+            'system.methodHelp',
+            'this:methodHelp',
+            array('string', 'string'),
             'Returns a documentation string for the specified method'
         );
     }
