@@ -11,12 +11,12 @@
  * Purpose: creates cached thumbnails
  * Home: http://www.cerdmann.com/thumb/
  * Copyright (C) 2005 Christoph Erdmann
- * 
+ *
  * This library is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option) any later version.
- * 
+ *
  * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.
- * 
- * You should have received a copy of the GNU Lesser General Public License along with this library; if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110, USA 
+ *
+ * You should have received a copy of the GNU Lesser General Public License along with this library; if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110, USA
  * -------------------------------------------------------------
  * Author:   Christoph Erdmann (CE) <smarty@cerdmann.com>
  * Internet: http://www.cerdmann.com
@@ -27,13 +27,13 @@
  * Author: Marcus Gueldenmeister (MG)
  * Internet: http://www.gueldenmeister.de/marcus/
  *
- * Author: Andreas Bsch (AB)
+ * Author: Andreas Bösch (AB)
  *
  */
- 
+
 /*
-$HeadURL: http://svn.textpattern.com/releases/4.0.6/source/textpattern/lib/class.thumb.php $
-$LastChangedRevision: 2329 $
+$HeadURL: https://textpattern.googlecode.com/svn/releases/4.2.0/source/textpattern/lib/class.thumb.php $
+$LastChangedRevision: 3107 $
 */
 
 $verbose = false;
@@ -44,16 +44,16 @@ class wet_thumb {
     var $height;	// The height of your thumbnail. The width (if not set) will be automatically calculated.
     var $longside;	// Set the longest side of the image if width, height and shortside is not set.
     var $shortside;	// Set the shortest side of the image if width, height and longside is not set.
-    var $extrapolate;  // Set to false if your source image is smaller than the calculated thumb and you do not want the image to get extrapolated.
-    var $crop;	// If set to true, image will be cropped in the center to destination width and height params, while keeping aspect ratio. Otherwise the image will get resized.
-    var $sharpen;	// Set to false if you dont want to use the Unsharp-Mask. Thumbnail creation will be faster, but quality is reduced.
-    var $hint; 	// If set to false the image will not have a lens-icon.
-    var $addgreytohint; // Set to false to get no lightgrey bottombar.
+    var $extrapolate;  // Set to 'false' if your source image is smaller than the calculated thumb and you do not want the image to get extrapolated.
+    var $crop;	// If set to 'true', image will be cropped in the center to destination width and height params, while keeping aspect ratio. Otherwise the image will get resized.
+    var $sharpen;	// Set to 'false' if you don't want to use the Unsharp-Mask. Thumbnail creation will be faster, but quality is reduced.
+    var $hint; 	// If set to 'false' the image will not have a lens-icon.
+    var $addgreytohint; // Set to 'false' to get no lightgrey bottombar.
     var $quality;	// JPEG image quality (0...100, defaults to 80).
     // link related params
     var $linkurl;    // Set to your target URL (a href="linkurl")
     var $html;       // Will be inserted in the image-tag
-   
+
     var $types = array('','.gif','.jpg','.png');
     var $_SRC;
     var $_DST;
@@ -61,7 +61,7 @@ class wet_thumb {
     /**
      * constructor
      */
-    function wet_thumb(  ) {        
+    function wet_thumb(  ) {
 	$this->extrapolate = false;
 	$this->crop = true;
 	$this->sharpen = true;
@@ -71,7 +71,7 @@ class wet_thumb {
 	$this->html = " alt=\"\" title=\"\" ";
 	$this->link = true;
     }
-    
+
     /**
      * write thumbnail file
      * @param	infile	image file name
@@ -80,10 +80,10 @@ class wet_thumb {
      */
     function write( $infile, $outfile ) {
         global $verbose;
-        
+
         if( $verbose )echo "writing thumb nail...";
-        
-	### Info ber Source (SRC) holen
+
+	### fetch source (SRC) info
 	$temp = getimagesize($infile);
 
 	$this->_SRC['file']		= $infile;
@@ -94,14 +94,14 @@ class wet_thumb {
 	$this->_SRC['filename'] 	= basename($infile);
 	//$this->_SRC['modified'] 	= filemtime($infile);
 
-	//Prfen ob das Orginalbild hoch oder querformatig ist
+	//check image orientation
 	if ($this->_SRC['width'] >= $this->_SRC['height']) {
 	    $this->_SRC['format'] = 'landscape';
 	} else {
 	    $this->_SRC['format'] = 'portrait';
 	}
 
-	### Info ber Destination (DST) holen
+	### fetch destination (DST) info
 	if (is_numeric($this->width) AND empty($this->height)) {
 		$this->_DST['width']	= $this->width;
 		$this->_DST['height']	= round($this->width/($this->_SRC['width']/$this->_SRC['height']));
@@ -115,8 +115,7 @@ class wet_thumb {
 		$this->_DST['height']	= $this->height;
 	}
 	elseif (is_numeric($this->longside) AND empty($this->shortside)) {
-	    // Das Grenverhltnis soll erhalten bleiben egal ob das Bild hoch oder querformatig ist.
-	    // Hier wurde die lange Seite angegeben
+	    // preserve aspect ratio based on provided height
 	    if ($this->_SRC['format'] == 'portrait') {
 		$this->_DST['height']	= $this->longside;
 		$this->_DST['width']	= round($this->longside/($this->_SRC['height']/$this->_SRC['width']));
@@ -127,8 +126,7 @@ class wet_thumb {
 	    }
         }
 	elseif (is_numeric($this->shortside)) {
-	    // Das Grenverhltnis soll erhalten bleiben egal ob das Bild hoch oder querformatig ist.
-	    // aber hier wurde die kurze Seite angeben.
+	    // preserve aspect ratio based on provided width
 	    if ($this->_SRC['format'] == 'portrait') {
 		$this->_DST['width']	= $this->shortside;
 		$this->_DST['height']	= round($this->shortside/($this->_SRC['width']/$this->_SRC['height']));
@@ -145,45 +143,45 @@ class wet_thumb {
         }
 
 
-	// Wenn das Ursprungsbild kleiner als das Ziel-Bild ist, soll nicht hochskaliert werden
+	// don't make the new image larger than the original image
 	if ($this->extrapolate === false && $this->_DST['height'] > $this->_SRC['height'] &&
 					    $this->_DST['width'] > $this->_SRC['width']) {
 	    $this->_DST['width'] = $this->_SRC['width'];
 	    $this->_DST['height'] = $this->_SRC['height'];
 	}
 
-	$this->_DST['type'] = $this->_SRC['type']; 
+	$this->_DST['type'] = $this->_SRC['type'];
 	$this->_DST['file'] = $outfile;
 
-	// Make sure we have enough memory if the image is large
+	// make sure we have enough memory if the image is large
 	if (max($this->_SRC['width'], $this->_SRC['height']) > 1024)
 		// this won't work on all servers but it's worth a try
 		ini_set('memory_limit', EXTRA_MEMORY);
 
-	// SRC einlesen
+	// read SRC
 	if ($this->_SRC['type'] == 1)	$this->_SRC['image'] = imagecreatefromgif($this->_SRC['file']);
 	elseif ($this->_SRC['type'] == 2)	$this->_SRC['image'] = imagecreatefromjpeg($this->_SRC['file']);
 	elseif ($this->_SRC['type'] == 3)	$this->_SRC['image'] = imagecreatefrompng($this->_SRC['file']);
 
-	// Soll beschnitten werden?
+	// crop image?
 	$off_w = 0;
 	$off_h = 0;
 	if($this->crop != false) {
 	    if($this->_SRC['height'] < $this->_SRC['width']) {
 		$ratio = (double)($this->_SRC['height'] / $this->_DST['height']);
 		$cpyWidth = round($this->_DST['width'] * $ratio);
-		if ($cpyWidth > $this->_SRC['width']) {           		
+		if ($cpyWidth > $this->_SRC['width']) {
 		    $ratio = (double)($this->_SRC['width'] / $this->_DST['width']);
 		    $cpyWidth = $this->_SRC['width'];
 		    $cpyHeight = round($this->_DST['height'] * $ratio);
 		    $off_w = 0;
-		    $off_h = round(($this->_SRC['height'] - $cpyHeight) / 2);                              
+		    $off_h = round(($this->_SRC['height'] - $cpyHeight) / 2);
 		    $this->_SRC['height'] = $cpyHeight;
 		}
-		else {           		
+		else {
 		    $cpyHeight = $this->_SRC['height'];
 		    $off_w = round(($this->_SRC['width'] - $cpyWidth) / 2);
-		    $off_h = 0;               
+		    $off_h = 0;
 		    $this->_SRC['width']= $cpyWidth;
 		}
 	    }
@@ -195,19 +193,23 @@ class wet_thumb {
 		    $cpyHeight = $this->_SRC['height'];
 		    $cpyWidth = round($this->_DST['width'] * $ratio);
 		    $off_w = round(($this->_SRC['width'] - $cpyWidth) / 2);
-		    $off_h = 0;               
-		    $this->_SRC['width']= $cpyWidth;               
+		    $off_h = 0;
+		    $this->_SRC['width']= $cpyWidth;
 		}
 		else {
 		    $cpyWidth = $this->_SRC['width'];
 		    $off_w = 0;
-		    $off_h = round(($this->_SRC['height'] - $cpyHeight) / 2);               
-		    $this->_SRC['height'] = $cpyHeight;               
+		    $off_h = round(($this->_SRC['height'] - $cpyHeight) / 2);
+		    $this->_SRC['height'] = $cpyHeight;
 		}
-	    }		
+	    }
 	}
 
-	// DST erstellen
+	// ensure non-zero height/width
+	if (!$this->_DST['height']) $this->_DST['height'] = 1;
+	if (!$this->_DST['width'])  $this->_DST['width']  = 1;
+
+	// create DST
 	$this->_DST['image'] = imagecreatetruecolor($this->_DST['width'], $this->_DST['height']);
 	imagecopyresampled($this->_DST['image'], $this->_SRC['image'], 0, 0, $off_w, $off_h, $this->_DST['width'], $this->_DST['height'], $this->_SRC['width'], $this->_SRC['height']);
 	if ($this->sharpen === true) {
@@ -218,9 +220,9 @@ class wet_thumb {
         $this->height =  $this->_DST['height'];
         $this->width =  $this->_DST['width'];
 
-	// Soll eine Lupe eingefgt werden?
+	// add magnifying glass?
 	if ( $this->hint === true) {
-	    //Soll der weie Balken wirklich hinzugefgt werden?
+	    // should we really add white bars?
 	    if ( $this->addgreytohint === true ) {
 		$trans = imagecolorallocatealpha($this->_DST['image'], 255, 255, 255, 25);
 		imagefilledrectangle($this->_DST['image'], 0, $this->_DST['height']-9, $this->_DST['width'], $this->_DST['height'], $trans);
@@ -232,8 +234,8 @@ class wet_thumb {
 	    imagedestroy($magnifier);
 	}
 
-        if ($verbose ) echo "... saving image ...";        
-	
+        if ($verbose ) echo "... saving image ...";
+
         if ($this->_DST['type'] == 1)	{
 	    imagetruecolortopalette($this->_DST['image'], false, 256);
 		if ( function_exists ('imagegif') ) {
@@ -250,14 +252,14 @@ class wet_thumb {
 	elseif ($this->_DST['type'] == 3) {
 	    imagepng($this->_DST['image'], $this->_DST['file']);
 	}
-	
+
         if ($verbose ) echo "... image successfully saved ...";
-        
+
 	imagedestroy($this->_DST['image']);
 	imagedestroy($this->_SRC['image']);
 	return true;
     }
-    
+
     /**
      * return a reference to the the thumbnailimage as a HTML <a> or <img> tag
      * @param	aslink	return an anchor tag to the source image
@@ -271,7 +273,7 @@ class wet_thumb {
                     "width=\"".$this->width."\" " .
                     "height=\"".$this->height."\" " .
                     "/>";
-                    
+
         if ( $aslink === true ) {
             return "<a href=\"" . ((empty($this->linkurl)) ? $this->_SRC['file'] : $this->linkurl) . "\" " .
                     (($aspopup === true) ? "target=\"_blank\"" : "") . ">" .
@@ -280,17 +282,17 @@ class wet_thumb {
         }
         else {
             return $imgtag;
-        }    
+        }
     }
 }
 /**
  * class txp_thumb: wrapper for wet_thumb interfacing the TxP repository
- */ 
+ */
 class txp_thumb extends wet_thumb {
-    
+
     var $m_ext;
     var $m_id;
-    
+
     /***
      * constructor
      * @param	$id	image id
@@ -305,16 +307,17 @@ class txp_thumb extends wet_thumb {
         }
         $this->wet_thumb(); // construct base class instance
     }
-    
+
     /**
      * create thumbnail image from source image
      * @return	boolean, true indicates success
      */
     function write( ) {
         if ( !isset($this->m_ext) ) return false;
-        
+
         if ( parent::write ( IMPATH.$this->m_id.$this->m_ext, IMPATH.$this->m_id.'t'.$this->m_ext ) ) {
-		    safe_update('txp_image', 'thumbnail = 1', 'id = '.$this->m_id);
+		    safe_update('txp_image', "thumbnail = 1, thumb_w = $this->width, thumb_h = $this->height", 'id = '.$this->m_id);
+		    chmod(IMPATH.$this->m_id.'t'.$this->m_ext, 0644);
 		    return true;
 		}
 		return false;
@@ -326,18 +329,18 @@ class txp_thumb extends wet_thumb {
      */
     function delete( ) {
         if (!isset($this->m_ext)) return false;
-        
+
 		if (unlink(IMPATH.$this->m_id.'t'.$this->m_ext)) {
 			safe_update('txp_image', 'thumbnail = 0', 'id = '.$this->m_id);
 	    	return true;
 		}
 	return false;
     }
-  
+
 }
 
 /**
- * Unsharp mask algorithm by Torstein Hnsi 2003 (thoensi_at_netcom_dot_no)
+ * Unsharp mask algorithm by Torstein Hønsi 2003 (thoensi_at_netcom_dot_no)
  * Christoph Erdmann: changed it a little, cause i could not reproduce the
  * darker blurred image, now it is up to 15% faster with same results
  * @param   img     image as a ressource
@@ -346,7 +349,7 @@ class txp_thumb extends wet_thumb {
  * @param   treshold    filter parameter
  * @return  sharpened image as a ressource
  *
- * 
+ *
  * This library is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option) any later version.
 */
 
@@ -357,19 +360,19 @@ function UnsharpMask($img, $amount, $radius, $threshold)    {
     if ($radius > 50) $radius = 50;
     $radius = $radius * 2;
     if ($threshold > 255) $threshold = 255;
-    
+
     $radius = abs(round($radius)); 	// Only integers make sense.
     if ($radius == 0) {	return $img; imagedestroy($img); break;	}
     $w = imagesx($img); $h = imagesy($img);
     $imgCanvas = $img;
     $imgCanvas2 = $img;
     $imgBlur = imagecreatetruecolor($w, $h);
-    
+
     // Gaussian blur matrix:
-    //	1	2	1		
-    //	2	4	2		
-    //	1	2	1		
-    
+    //	1	2	1
+    //	2	4	2
+    //	1	2	1
+
     // Move copies of the image around one pixel at the time and merge them with weight
     // according to the matrix. The same matrix is simply repeated for higher radii.
     for ($i = 0; $i < $radius; $i++)
@@ -384,8 +387,8 @@ function UnsharpMask($img, $amount, $radius, $threshold)    {
             imagecopymerge ($imgBlur, $imgCanvas, 0, 1, 0, 0, $w, $h, 16.666667); // down
             imagecopymerge ($imgBlur, $imgCanvas, 0, 0, 0, 0, $w, $h, 50); // center
             }
-    $imgCanvas = $imgBlur;	
-            
+    $imgCanvas = $imgBlur;
+
     // Calculate the difference between the blurred pixels and the original
     // and set the pixels
     for ($x = 0; $x < $w; $x++) { // each row
@@ -398,13 +401,13 @@ function UnsharpMask($img, $amount, $radius, $threshold)    {
             $rBlur = (($rgbBlur >> 16) & 0xFF);
             $gBlur = (($rgbBlur >> 8) & 0xFF);
             $bBlur = ($rgbBlur & 0xFF);
-    
+
             // When the masked pixels differ less from the original
             // than the threshold specifies, they are set to their original value.
             $rNew = (abs($rOrig - $rBlur) >= $threshold) ? max(0, min(255, ($amount * ($rOrig - $rBlur)) + $rOrig)) : $rOrig;
             $gNew = (abs($gOrig - $gBlur) >= $threshold) ? max(0, min(255, ($amount * ($gOrig - $gBlur)) + $gOrig)) : $gOrig;
             $bNew = (abs($bOrig - $bBlur) >= $threshold) ? max(0, min(255, ($amount * ($bOrig - $bBlur)) + $bOrig)) : $bOrig;
-            
+
             if (($rOrig != $rNew) || ($gOrig != $gNew) || ($bOrig != $bNew)) {
                 $pixCol = ImageColorAllocate($img, $rNew, $gNew, $bNew);
                 ImageSetPixel($img, $x, $y, $pixCol);
