@@ -1,7 +1,7 @@
 <?php
 /*
-$HeadURL: http://svn.textpattern.com/releases/4.0.6/source/textpattern/lib/constants.php $
-$LastChangedRevision: 2361 $
+$HeadURL: https://textpattern.googlecode.com/svn/releases/4.2.0/source/textpattern/lib/constants.php $
+$LastChangedRevision: 3133 $
 */
 
 $old_level = error_reporting(E_ALL ^ (E_NOTICE));
@@ -27,6 +27,10 @@ else
 define('MAGIC_QUOTES_GPC', get_magic_quotes_gpc());
 
 define('REGEXP_UTF8', @preg_match('@\pL@u', 'q'));
+define('NULLDATETIME', '\'0000-00-00 00:00:00\'');
+
+define('PERMLINKURL', 0);
+define('PAGELINKURL', 1);
 
 define('EXTRA_MEMORY', '32M');
 
@@ -34,7 +38,17 @@ define('IS_CGI', substr(PHP_SAPI, 0, 3) == 'cgi' );
 define('IS_FASTCGI', IS_CGI and empty($_SERVER['FCGI_ROLE']) and empty($_ENV['FCGI_ROLE']) );
 define('IS_APACHE', !IS_CGI and substr(PHP_SAPI, 0, 6) == 'apache' );
 
+define('PREF_PRIVATE', true);
+define('PREF_GLOBAL', false);
+define('PREF_BASIC', 0);
+define('PREF_ADVANCED', 1);
+define('PREF_HIDDEN', 2);
+
+define('PLUGIN_HAS_PREFS', 0x0001);
+define('PLUGIN_LIFECYCLE_NOTIFY', 0x0002);
+define('PLUGIN_RESERVED_FLAGS', 0x0fff); // reserved bits for use by Textpattern core
+
 error_reporting($old_level);
 unset($old_level);
 
-?>
\ No newline at end of file
+?>
