@@ -1,8 +1,8 @@
 <?php
 
 /*
-$HeadURL: http://svn.textpattern.com/releases/4.0.6/source/textpattern/lib/txplib_html.php $
-$LastChangedRevision: 2696 $
+$HeadURL: https://textpattern.googlecode.com/svn/releases/4.2.0/source/textpattern/lib/txplib_html.php $
+$LastChangedRevision: 3255 $
 */
 
 	define("t","\t");
@@ -14,16 +14,11 @@ $LastChangedRevision: 2696 $
 // -------------------------------------------------------------
 	function end_page()
 	{
-		global $txp_user,$event;
-		if($event!='tag') {
-			echo '<div id="end_page">',
-			navPop().n,
-			'<a href="http://www.textpattern.com"><img src="txp_img/carver.gif" width="60" height="48" border="0" alt="" /></a>'.n;
-			echo graf('Textpattern &#183; '.txp_version).n;
-			echo($txp_user)
-			?	graf(gTxt('logged_in_as').' '.span(htmlspecialchars($txp_user)).br.
-					'<a href="index.php?logout=1">'.gTxt('logout').'</a>', ' id="moniker"').n.'</div>'
-			:	'</div>';
+		global $txp_user, $event, $app_mode, $theme;
+
+		if ($app_mode != 'async' && $event != 'tag') {
+			echo pluggable_ui('admin_side', 'footer', $theme->footer());
+			callback_event('admin_side', 'body_end');
 			echo n.'</body>'.n.'</html>';
 		}
 	}
@@ -85,10 +80,10 @@ $LastChangedRevision: 2696 $
 	}
 
 // -------------------------------------------------------------
-	function hCell($text="",$caption="")
+	function hCell($text='',$caption='',$atts='')
 	{
-		$text = (!$text) ? sp : $text;
-		return tag($text,'th');
+		$text = ('' === $text) ? sp : $text;
+		return tag($text,'th',$atts);
 	}
 
 // -------------------------------------------------------------
@@ -142,13 +137,13 @@ $LastChangedRevision: 2696 $
 			return join('', array(
 				'<a href="'.$url.'" class="dlink" onclick="return verify(\'',
 				($verify) ? gTxt($verify) : gTxt('confirm_delete_popup'),
-				'\')">&#215;</a>'
+				'\')">×</a>'
 			));
 		}
 
 		return join('', array(
 			'<form method="post" action="index.php" onsubmit="return confirm(\''.gTxt('confirm_delete_popup').'\');">',
-			 fInput('submit', '', '&#215;', 'smallerbox'),
+			 fInput('submit', '', '×', 'smallerbox'),
 			 eInput($event).
 			 sInput($step),
 			 hInput($thing, $value),
@@ -194,8 +189,22 @@ $LastChangedRevision: 2696 $
 
 // -------------------------------------------------------------
 
-	function nav_form($event, $page, $numPages, $sort, $dir, $crit, $search_method)
+	function nav_form($event, $page, $numPages, $sort, $dir, $crit, $search_method, $total=0, $limit=0)
 	{
+		global $theme;
+		if ($crit && $total > 1)
+		{
+			$out[] = $theme->announce(
+				gTxt('showing_search_results',
+					array(
+						'{from}'	=> (($page - 1) * $limit) + 1,
+						'{to}' 		=> min($total, $page * $limit),
+						'{total}' 	=> $total
+						)
+					)
+				);
+		}
+
 		if ($numPages > 1)
 		{
 			$option_list = array();
@@ -228,18 +237,19 @@ $LastChangedRevision: 2696 $
 				sp.PrevNextLink($event, $page + 1, gTxt('next'), 'next', $sort, $dir, $crit, $search_method) :
 				sp.tag(gTxt('next').' &#8250;', 'span', ' class="navlink-disabled"');
 
-			return '<form class="prev-next" method="get" action="index.php">'.
+			$out[] = '<form class="prev-next" method="get" action="index.php">'.
 				n.eInput($event).
 				( $sort ? n.hInput('sort', $sort).n.hInput('dir', $dir) : '' ).
 				( $crit ? n.hInput('crit', $crit).n.hInput('search_method', $search_method) : '' ).
 				join('', $nav).
 				'</form>';
 		}
-
 		else
 		{
-			return graf($page.'/'.$numPages, ' class="prev-next"');
+			$out[] = graf($page.'/'.$numPages, ' class="prev-next"');
 		}
+
+		return join(n, $out);
 	}
 
 // -------------------------------------------------------------
@@ -252,7 +262,7 @@ $LastChangedRevision: 2696 $
 // -------------------------------------------------------------
 	function startTable($type,$align='',$class='',$p='',$w='')
 	{
-		if (!$p) $p = ($type=='edit') ? 3 : 0;
+		if ('' === $p) $p = ($type=='edit') ? 3 : 0;
 		$align = (!$align) ? 'center' : $align;
 		$class = ($class) ? ' class="'.$class.'"' : '';
 		$width = ($w) ? ' width="'.$w.'"' : '';
@@ -276,7 +286,7 @@ $LastChangedRevision: 2696 $
 // -------------------------------------------------------------
 	function td($content='',$width='',$class='',$id='')
 	{
-		$content = (!$content) ? '&#160;' : $content;
+		$content = ('' === $content) ? '&#160;' : $content;
 		$atts[] = ($width)  ? ' width="'.$width.'"' : '';
 		$atts[] = ($class)  ? ' class="'.$class.'"' : '';
 		$atts[] = ($id)  ? ' id="'.$id.'"' : '';
@@ -351,7 +361,7 @@ $LastChangedRevision: 2696 $
 // -------------------------------------------------------------
 	function tag($content,$tag,$atts='')
 	{
-		return ($content) ? '<'.$tag.$atts.'>'.$content.'</'.$tag.'>' : '';
+		return ('' !== $content) ? '<'.$tag.$atts.'>'.$content.'</'.$tag.'>' : '';
 	}
 
 // -------------------------------------------------------------
@@ -478,7 +488,7 @@ $LastChangedRevision: 2696 $
 	}
 
 //-------------------------------------------------------------
-	function messenger($thing,$thething,$action)
+	function messenger($thing, $thething='', $action='')
 	{
 		return gTxt($thing).' '.strong($thething).' '.gTxt($action);
 	}
@@ -518,7 +528,9 @@ $LastChangedRevision: 2696 $
 
 		$label_id = ($label_id) ? $label_id : $event.'-upload';
 
-		return n.n.'<form'.$class.' method="post" enctype="multipart/form-data" action="index.php">'.
+		$argv = func_get_args();
+		return pluggable_ui($event.'_ui', 'upload_form',
+			n.n.'<form'.$class.' method="post" enctype="multipart/form-data" action="index.php">'.
 			n.'<div>'.
 
 			(!empty($max_file_size)? n.hInput('MAX_FILE_SIZE', $max_file_size): '').
@@ -539,7 +551,8 @@ $LastChangedRevision: 2696 $
 			).
 
 			n.'</div>'.
-			n.'</form>';
+			n.'</form>',
+			$argv);
 	}
 
 //-------------------------------------------------------------
