@@ -13,8 +13,8 @@
 
 	Use of this software denotes acceptance of the Textpattern license agreement
 
-$HeadURL: http://svn.textpattern.com/releases/4.0.6/source/textpattern/publish.php $
-$LastChangedRevision: 2777 $
+$HeadURL: https://textpattern.googlecode.com/svn/releases/4.2.0/source/textpattern/publish.php $
+$LastChangedRevision: 3258 $
 
 */
 
@@ -43,6 +43,11 @@ $LastChangedRevision: 2777 $
 		// start the clock for runtime
 	$microstart = getmicrotime();
 
+		// initialize parse trace globals
+	$txptrace        = array();
+	$txptracelevel   = 0;
+	$txp_current_tag = '';
+
 		// get all prefs as an array
 	$prefs = get_prefs();
 
@@ -105,6 +110,9 @@ $LastChangedRevision: 2777 $
 		//i18n: $textarray = load_lang('en-gb');
 	$textarray = load_lang(LANG);
 
+		// tidy up the site
+	janitor();
+
 		// here come the plugins
 	if ($use_plugins) load_plugins();
 
@@ -114,11 +122,16 @@ $LastChangedRevision: 2777 $
 
 	$pretext = !isset($pretext) ? array() : $pretext;
 	$pretext = array_merge($pretext, pretext($s,$prefs));
+	callback_event('pretext_end');
 	extract($pretext);
 
 	// Now that everything is initialized, we can crank down error reporting
 	set_error_level($production_status);
 
+	if( isset($feed) )
+		exit($feed());
+
+
 	if (gps('parentid') && gps('submit')) {
 		saveComment();
 	} elseif (gps('parentid') and $comments_mode==1) { // popup comments?
@@ -203,17 +216,18 @@ $LastChangedRevision: 2777 $
 
 		callback_event('pretext');
 
+			// set messy variables
+		$out =  makeOut('id','s','c','q','pg','p','month','author');
+
 		if(gps('rss')) {
 			include txpath.'/publish/rss.php';
-			exit(rss());
+			$out['feed'] = 'rss';
 		}
 
 		if(gps('atom')) {
 			include txpath.'/publish/atom.php';
-			exit(atom());
+			$out['feed'] = 'atom';
 		}
-			// set messy variables
-		$out =  makeOut('id','s','c','q','pg','p','month','author');
 
 			// some useful vars for taghandlers, plugins
 		$out['request_uri'] = preg_replace("|^https?://[^/]+|i","",serverSet('REQUEST_URI'));
@@ -251,10 +265,12 @@ $LastChangedRevision: 2777 $
 				switch($u1) {
 
 					case 'atom':
-						include txpath.'/publish/atom.php'; exit(atom());
+						include txpath.'/publish/atom.php';
+						$out['feed'] = 'atom'; break;
 
 					case 'rss':
-						include txpath.'/publish/rss.php'; exit(rss());
+						include txpath.'/publish/rss.php';
+						$out['feed'] = 'rss'; break;
 
 					// urldecode(strtolower(urlencode())) looks ugly but is the only way to
 					// make it multibyte-safe without breaking backwards-compatibility
@@ -320,8 +336,8 @@ $LastChangedRevision: 2777 $
 								}
 								else {
 									$rs = lookupByTitleSection($u2,$u1);
-									$out['id'] = @$rs['ID'];
-									$out['s'] = @$rs['Section'];
+									$out['id'] = isset($rs['ID']) ? $rs['ID'] : '';
+									$out['s'] = isset($rs['Section']) ? $rs['Section'] : '';
 									$is_404 = (empty($out['s']) or empty($out['id']));
 								}
 							break;
@@ -383,6 +399,21 @@ $LastChangedRevision: 2777 $
 			}
 		}
 
+		// allow article preview
+		if (gps('txpreview') and is_logged_in())
+		{
+			global $nolog;
+
+			$nolog = true;
+			$rs = safe_row("ID as id,Section as s",'textpattern','ID = '.intval(gps('txpreview')).' limit 1');
+
+			if ($rs and $is_404)
+			{
+				$is_404 = false;
+				$out = array_merge($out, $rs);
+			}
+		}
+
 		// Stats: found or not
 		$out['status'] = ($is_404 ? '404' : '200');
 
@@ -408,20 +439,26 @@ $LastChangedRevision: 2777 $
 
 		// hackish
 		global $is_article_list;
-		if(empty($id)) $is_article_list = true;
+		if (empty($id)) $is_article_list = true;
 
-			// by this point we should know the section, so grab its page and css
-		$rs = safe_row("*", "txp_section", "name = '".doSlash($s)."' limit 1");
-		$out['page'] = @$rs['page'];
+		// by this point we should know the section, so grab its page and css
+		$rs = safe_row("page, css", "txp_section", "name = '".doSlash($s)."' limit 1");
+		$out['page'] = isset($rs['page']) ? $rs['page'] : '';
+		$out['css'] = isset($rs['css']) ? $rs['css'] : '';
 
-		if(is_numeric($id)) {
-			$a = safe_row('*, unix_timestamp(Posted) as uPosted', 'textpattern', 'ID='.intval($id).' and Status in (4,5)');
+		if (is_numeric($id) and !$is_404) {
+			$a = safe_row('*, unix_timestamp(Posted) as uPosted, unix_timestamp(Expires) as uExpires, unix_timestamp(LastMod) as uLastMod', 'textpattern', 'ID='.intval($id).(gps('txpreview') ? '' : ' and Status in (4,5)'));
 			if ($a) {
 				$Posted             = $a['Posted'];
 				$out['id_keywords'] = $a['Keywords'];
 				$out['id_author']   = $a['AuthorID'];
 				populateArticleData($a);
 
+				$uExpires = $a['uExpires'];
+				if ($uExpires and time() > $uExpires and !$publish_expired_articles) {
+					$out['status'] = '410';
+				}
+
 				if ($np = getNextPrev($id, $Posted, $s))
 					$out = array_merge($out, $np);
 			}
@@ -453,6 +490,9 @@ $LastChangedRevision: 2777 $
 		if ($pretext['status'] == '404')
 			txp_die(gTxt('404_not_found'), '404');
 
+		if ($pretext['status'] == '410')
+			txp_die(gTxt('410_gone'), '410');
+
 		$html = safe_field('user_html','txp_page',"name='".doSlash($pretext['page'])."'");
 		if (!$html)
 			txp_die(gTxt('unknown_section'), '404');
@@ -467,7 +507,7 @@ $LastChangedRevision: 2777 $
 		$pretext['secondpass'] = true;
 		trace_add('[ ~~~ '.gTxt('secondpass').' ~~~ ]');
 		$html = parse($html); // the function so nice, he ran it twice
-		$html = ($prefs['allow_page_php_scripting']) ? evalString($html) : $html;
+		if ($prefs['allow_page_php_scripting']) $html = evalString($html);
 
 		// make sure the page has an article tag if necessary
 		if (!$has_article_tag and $production_status != 'live' and (!empty($pretext['id']) or !empty($pretext['c']) or !empty($pretext['q']) or !empty($pretext['pg'])))
@@ -480,11 +520,12 @@ $LastChangedRevision: 2777 $
 		if (in_array($production_status, array('debug', 'testing'))) {
 			$microdiff = (getmicrotime() - $microstart);
 			echo n,comment('Runtime:    '.substr($microdiff,0,6));
-			echo n,comment('Query time: '.$qtime);
+			echo n,comment('Query time: '.sprintf('%02.6f', $qtime));
 			echo n,comment('Queries: '.$qcount);
 			echo maxMemUsage('end of textpattern()',1);
 			if (!empty($txptrace) and is_array($txptrace))
-				echo n, comment('txp tag trace: '.n.join(n, $txptrace).n);
+				echo n, comment('txp tag trace: '.n.str_replace('--','&shy;&shy;',join(n, $txptrace)).n);
+				// '&shy;&shy;' is *no* tribute to Kajagoogoo, but an attempt to avoid prematurely terminating HTML comments
 		}
 
 		callback_event('textpattern_end');
@@ -499,8 +540,8 @@ $LastChangedRevision: 2777 $
 			$cssname = safe_field('css','txp_section',"name='".doSlash($s)."'");
 		}
 
-		$css = safe_field('css','txp_css',"name='".doSlash($cssname)."'");
-		if ($css) echo base64_decode($css);
+		if (isset($cssname)) $css = safe_field('css','txp_css',"name='".doSlash($cssname)."'");
+		if (isset($css)) echo base64_decode($css);
 	}
 
 //	article() is called when parse() finds a <txp:article /> tag.
@@ -508,7 +549,7 @@ $LastChangedRevision: 2777 $
 //	otherwise, output a list.
 
 // -------------------------------------------------------------
-	function article($atts)
+	function article($atts, $thing = NULL)
 	{
 		global $is_article_body, $has_article_tag;
 		if ($is_article_body) {
@@ -516,13 +557,13 @@ $LastChangedRevision: 2777 $
 			return '';
 		}
 		$has_article_tag = true;
-		return parseArticles($atts);
+		return parseArticles($atts, '0', $thing);
 	}
 
 // -------------------------------------------------------------
-	function doArticles($atts, $iscustom)
+	function doArticles($atts, $iscustom, $thing = NULL)
 	{
-		global $pretext, $prefs, $txpcfg;
+		global $pretext, $prefs;
 		extract($pretext);
 		extract($prefs);
 		$customFields = getCustomFields();
@@ -540,8 +581,8 @@ $LastChangedRevision: 2777 $
 			'excerpted' => '',
 			'author'    => '',
 			'sort'      => '',
-			'sortby'    => '',
-			'sortdir'   => '',
+			'sortby'    => '', // deprecated in 4.0.4
+			'sortdir'   => '', // deprecated in 4.0.4
 			'month'     => '',
 			'keywords'  => '',
 			'frontpage' => '',
@@ -553,6 +594,11 @@ $LastChangedRevision: 2777 $
 			'searchsticky' => 0,
 			'allowoverride' => (!$q and !$iscustom),
 			'offset'    => 0,
+			'wraptag'	=> '',
+			'break'		=> '',
+			'label'		=> '',
+			'labeltag'	=> '',
+			'class'		=> ''
 		)+$customlAtts,$atts);
 
 		// if an article ID is specified, treat it as a custom list
@@ -571,46 +617,65 @@ $LastChangedRevision: 2777 $
 		}
 		extract($theAtts);
 
+		// if a listform is specified, $thing is for doArticle() - hence ignore here.
+		if (!empty($listform)) $thing = '';
+
 		$pageby = (empty($pageby) ? $limit : $pageby);
 
 		// treat sticky articles differently wrt search filtering, etc
-		if (!is_numeric($status))
-			$status = getStatusNum($status);
+		$status = in_array(strtolower($status), array('sticky', '5')) ? 5 : 4;
 		$issticky = ($status == 5);
 
-		//give control to search, if necesary
-		if($q && !$iscustom && !$issticky)
+		// give control to search, if necessary
+		if ($q && !$iscustom && !$issticky)
 		{
 			include_once txpath.'/publish/search.php';
 
 			$s_filter = ($searchall ? filterSearch() : '');
-			$q        = doSlash($q);
-			$match    = ", match (Title,Body) against ('$q') as score";
-			$search   = " and (Title rlike '$q' or Body rlike '$q') $s_filter";
+			$q = doSlash($q);
+
+            		// searchable article fields are limited to the columns of
+            		// the textpattern table and a matching fulltext index must exist.
+			$cols = do_list($searchable_article_fields);
+			if (empty($cols) or $cols[0] == '') $cols = array('Title', 'Body');
+
+			$match = ', match (`'.join('`, `', $cols)."`) against ('$q') as score";
+			for ($i = 0; $i < count($cols); $i++)
+			{
+				$cols[$i] = "`$cols[$i]` rlike '$q'";
+			}
+			$cols = join(" or ", $cols);
+			$search = " and ($cols) $s_filter";
 
 			// searchall=0 can be used to show search results for the current section only
 			if ($searchall) $section = '';
-			if (!$sort) $sort='score desc';
+			if (!$sort) $sort = 'score desc';
 		}
 		else {
 			$match = $search = '';
-			if (!$sort) $sort='Posted desc';
+			if (!$sort) $sort = 'Posted desc';
 		}
 
 		// for backwards compatibility
 		// sortby and sortdir are deprecated
 		if ($sortby)
 		{
+			trigger_error(gTxt('deprecated_attribute', array('{name}' => 'sortby')), E_USER_NOTICE);
+
 			if (!$sortdir)
 			{
 				$sortdir = 'desc';
 			}
-
+			else
+			{
+				trigger_error(gTxt('deprecated_attribute', array('{name}' => 'sortdir')), E_USER_NOTICE);
+			}
 			$sort = "$sortby $sortdir";
 		}
 
 		elseif ($sortdir)
 		{
+			trigger_error(gTxt('deprecated_attribute', array('{name}' => 'sortdir')), E_USER_NOTICE);
 			$sort = "Posted $sortdir";
 		}
 
@@ -622,7 +687,7 @@ $LastChangedRevision: 2777 $
 		$excerpted = ($excerpted=='y')  ? " and Excerpt !=''" : '';
 		$author    = (!$author)    ? '' : " and AuthorID IN ('".join("','", doSlash(do_list($author)))."')";
 		$month     = (!$month)     ? '' : " and Posted like '".doSlash($month)."%'";
-		$id        = (!$id)        ? '' : " and ID = '".intval($id)."'";
+		$id        = (!$id)        ? '' : " and ID IN (".join(',', array_map('intval', do_list($id))).")";
 		switch ($time) {
 			case 'any':
 				$time = ""; break;
@@ -631,6 +696,9 @@ $LastChangedRevision: 2777 $
 			default:
 				$time = " and Posted <= now()";
 		}
+		if (!$publish_expired_articles) {
+			$time .= " and (now() <= Expires or Expires = ".NULLDATETIME.")";
+		}
 
 		$custom = '';
 
@@ -688,7 +756,7 @@ $LastChangedRevision: 2777 $
 			$pgoffset = $offset;
 		}
 
-		$rs = safe_rows_start("*, unix_timestamp(Posted) as uPosted".$match, 'textpattern',
+		$rs = safe_rows_start("*, unix_timestamp(Posted) as uPosted, unix_timestamp(Expires) as uExpires, unix_timestamp(LastMod) as uLastMod".$match, 'textpattern',
 		$where.' order by '.doSlash($sort).' limit '.intval($pgoffset).', '.intval($limit));
 		// get the form name
 		if ($q and !$iscustom and !$issticky)
@@ -698,6 +766,7 @@ $LastChangedRevision: 2777 $
 
 		if ($rs) {
 			$count = 0;
+			$last = numRows($rs);
 
 			$articles = array();
 			while($a = nextRow($rs)) {
@@ -705,7 +774,7 @@ $LastChangedRevision: 2777 $
 				populateArticleData($a);
 				global $thisarticle, $uPosted, $limit;
 				$thisarticle['is_first'] = ($count == 1);
-				$thisarticle['is_last'] = ($count == numRows($rs));
+				$thisarticle['is_last'] = ($count == $last);
 
 				if (@constant('txpinterface') === 'admin' and gps('Form')) {
 					$articles[] = parse(gps('Form'));
@@ -714,7 +783,7 @@ $LastChangedRevision: 2777 $
 					$articles[] = parse_form($a['override_form']);
 				}
 				else {
-					$articles[] = parse_form($fname);
+					$articles[] = ($thing) ? parse($thing) : parse_form($fname);
 				}
 
 				// sending these to paging_link(); Required?
@@ -723,7 +792,7 @@ $LastChangedRevision: 2777 $
 				unset($GLOBALS['thisarticle']);
 			}
 
-			return join('',$articles);
+			return doLabel($label, $labeltag).doWrap($articles, $wraptag, $break, $class);
 		}
 	}
 
@@ -755,7 +824,7 @@ $LastChangedRevision: 2777 $
 	}
 
 // -------------------------------------------------------------
-	function doArticle($atts)
+	function doArticle($atts, $thing = NULL)
 	{
 		global $pretext,$prefs, $thisarticle;
 		extract($prefs);
@@ -769,9 +838,12 @@ $LastChangedRevision: 2777 $
 			'status'        => '4',
 		),$atts, 0));
 
-		if ($status and !is_numeric($status))
+		// if a form is specified, $thing is for doArticles() - hence ignore $thing here.
+		if (!empty($atts['form'])) $thing = '';
+
+		if ($status)
 		{
-			$status = getStatusNum($status);
+			$status = in_array(strtolower($status), array('sticky', '5')) ? 5 : 4;
 		}
 
 		if (empty($thisarticle) or $thisarticle['thisid'] != $id)
@@ -780,7 +852,7 @@ $LastChangedRevision: 2777 $
 
 			$q_status = ($status ? 'and Status = '.intval($status) : 'and Status in (4,5)');
 
-			$rs = safe_row("*, unix_timestamp(Posted) as uPosted",
+			$rs = safe_row("*, unix_timestamp(Posted) as uPosted, unix_timestamp(Expires) as uExpires, unix_timestamp(LastMod) as uLastMod",
 					"textpattern", 'ID = '.intval($id)." $q_status limit 1");
 
 			if ($rs) {
@@ -789,15 +861,20 @@ $LastChangedRevision: 2777 $
 			}
 		}
 
-		if (!empty($thisarticle) and $thisarticle['status'] == $status)
+		if (!empty($thisarticle) and ($thisarticle['status'] == $status or gps('txpreview')))
 		{
 			extract($thisarticle);
 			$thisarticle['is_first'] = 1;
 			$thisarticle['is_last'] = 1;
 
-			$form = ($allowoverride and $override_form) ? $override_form : $form;
-
-			$article = parse_form($form);
+			if ($allowoverride and $override_form)
+			{
+				$article = parse_form($override_form);
+			}
+			else
+			{
+				$article = ($thing) ? parse($thing) : parse_form($form);
+			}
 
 			if ($use_comments and $comments_auto_append)
 			{
@@ -811,19 +888,19 @@ $LastChangedRevision: 2777 $
 	}
 
 // -------------------------------------------------------------
-	function article_custom($atts)
+	function article_custom($atts, $thing = NULL)
 	{
-		return parseArticles($atts, '1');
+		return parseArticles($atts, '1', $thing);
 	}
 
 // -------------------------------------------------------------
-	function parseArticles($atts, $iscustom = '')
+	function parseArticles($atts, $iscustom = 0, $thing = NULL)
 	{
 		global $pretext, $is_article_list;
 		$old_ial = $is_article_list;
 		$is_article_list = ($pretext['id'] && !$iscustom)? false : true;
 		article_push();
-		$r = ($is_article_list)? doArticles($atts, $iscustom) : doArticle($atts);
+		$r = ($is_article_list)? doArticles($atts, $iscustom, $thing) : doArticle($atts, $thing);
 		article_pop();
 		$is_article_list = $old_ial;
 
@@ -836,48 +913,51 @@ $LastChangedRevision: 2777 $
 // new article tags.
 	function populateArticleData($rs)
 	{
+		global $thisarticle;
 		extract($rs);
 
 		trace_add("[".gTxt('Article')." $ID]");
-		$out['thisid']          = $ID;
-		$out['posted']          = $uPosted;
-		$out['modified']	= $LastMod;
-		$out['annotate']        = $Annotate;
-		$out['comments_invite'] = $AnnotateInvite;
-		$out['authorid']        = $AuthorID;
-		$out['title']           = $Title;
-		$out['url_title']       = $url_title;
-		$out['category1']       = $Category1;
-		$out['category2']       = $Category2;
-		$out['section']         = $Section;
-		$out['keywords']        = $Keywords;
-		$out['article_image']   = $Image;
-		$out['comments_count']  = $comments_count;
-		$out['body']            = $Body_html;
-		$out['excerpt']         = $Excerpt_html;
-		$out['override_form']   = $override_form;
-		$out['status']          = $Status;
+		$thisarticle['thisid']          = $ID;
+		$thisarticle['posted']          = $uPosted;
+		$thisarticle['expires']         = $uExpires;
+		$thisarticle['modified']		= $uLastMod;
+		$thisarticle['annotate']        = $Annotate;
+		$thisarticle['comments_invite'] = $AnnotateInvite;
+		$thisarticle['authorid']        = $AuthorID;
+		$thisarticle['title']           = $Title;
+		$thisarticle['url_title']       = $url_title;
+		$thisarticle['category1']       = $Category1;
+		$thisarticle['category2']       = $Category2;
+		$thisarticle['section']         = $Section;
+		$thisarticle['keywords']        = $Keywords;
+		$thisarticle['article_image']   = $Image;
+		$thisarticle['comments_count']  = $comments_count;
+		$thisarticle['body']            = $Body_html;
+		$thisarticle['excerpt']         = $Excerpt_html;
+		$thisarticle['override_form']   = $override_form;
+		$thisarticle['status']          = $Status;
 
 		$custom = getCustomFields();
 		if ($custom) {
 			foreach ($custom as $i => $name)
-				$out[$name] = $rs['custom_' . $i];
+				$thisarticle[$name] = $rs['custom_' . $i];
 		}
 
-		global $thisarticle;
-		$thisarticle = $out;
 	}
 
 // -------------------------------------------------------------
 	function getNeighbour($Posted, $s, $type)
 	{
+		global $prefs;
+		extract($prefs);
+		$expired = ($publish_expired_articles) ? '' : ' and (now() <= Expires or Expires = '.NULLDATETIME.')';
 		$type = ($type == '>') ? '>' : '<';
 		$safe_name = safe_pfx('textpattern');
 		$q = array(
 			"select ID, Title, url_title, unix_timestamp(Posted) as uposted
 			from ".$safe_name." where Posted $type '".doSlash($Posted)."'",
 			($s!='' && $s!='default') ? "and Section = '".doSlash($s)."'" : filterFrontPage(),
-			'and Status=4 and Posted < now() order by Posted',
+			'and Status=4 and Posted < now()'.$expired.' order by Posted',
 			($type=='<') ? 'desc' : 'asc',
 			'limit 1'
 		);
@@ -923,55 +1003,111 @@ $LastChangedRevision: 2777 $
 	}
 
 // -------------------------------------------------------------
-	function parse($text)
+	function parse($thing)
 	{
-		$f = '/<txp:(\S+)\b(.*)(?:(?<!br )(\/))?'.chr(62).'(?(3)|(.+)<\/txp:\1>)/sU';
-		return preg_replace_callback($f, 'processTags', $text);
+		$f = '@(</?txp:\w+(?:\s+\w+\s*=\s*(?:"(?:[^"]|"")*"|\'(?:[^\']|\'\')*\'|[^\s\'"/>]+))*\s*/?'.chr(62).')@s';
+		$t = '@:(\w+)(.*?)/?.$@s';
+
+		$parsed = preg_split($f, $thing, -1, PREG_SPLIT_DELIM_CAPTURE);
+
+		$level  = 0;
+		$out    = '';
+		$inside = '';
+		$istag  = FALSE;
+
+		foreach ($parsed as $chunk)
+		{
+			if ($istag)
+			{
+				if ($level === 0)
+				{
+					preg_match($t, $chunk, $tag);
+
+					if (substr($chunk, -2, 1) === '/')
+					{ # self closing
+						$out .= processTags($tag[1], $tag[2]);
+					}
+					else
+					{ # opening
+						$level++;
+					}
+				}
+				else
+				{
+					if (substr($chunk, 1, 1) === '/')
+					{ # closing
+						if (--$level === 0)
+						{
+							$out  .= processTags($tag[1], $tag[2], $inside);
+							$inside = '';
+						}
+						else
+						{
+							$inside .= $chunk;
+						}
+					}
+					elseif (substr($chunk, -2, 1) !== '/')
+					{ # opening inside open
+						++$level;
+						$inside .= $chunk;
+					}
+					else
+					{
+						$inside .= $chunk;
+					}
+				}
+			}
+			else
+			{
+				if ($level)
+				{
+					$inside .= $chunk;
+				}
+				else
+				{
+					$out .= $chunk;
+				}
+			}
+
+			$istag = !$istag;
+		}
+
+		return $out;
 	}
 
 // -------------------------------------------------------------
 
-	function processTags($matches)
+	function processTags($tag, $atts, $thing = NULL)
 	{
-		global $pretext, $production_status, $txptrace, $txptracelevel, $txp_current_tag;
+		global $production_status, $txptrace, $txptracelevel, $txp_current_tag;
 
-		$tag = $matches[1];
+		if ($production_status !== 'live')
+		{
+			$old_tag = $txp_current_tag;
 
-		$trouble_makers = array(
-			'link'
-		);
+			$txp_current_tag = '<txp:'.$tag.$atts.(isset($thing) ? '>' : '/>');
 
-		if (in_array($tag, $trouble_makers))
+			trace_add($txp_current_tag);
+			++$txptracelevel;
+
+			if ($production_status === 'debug')
+			{
+				maxMemUsage($txp_current_tag);
+			}
+		}
+
+		if ($tag === 'link')
 		{
 			$tag = 'tpt_'.$tag;
 		}
 
-		$atts = isset($matches[2]) ? splat($matches[2]) : '';
-		$thing = isset($matches[4]) ? $matches[4] : null;
-
-		$old_tag = @$txp_current_tag;
-
-		$txp_current_tag = '<txp:'.$tag.
-			($atts ? $matches[2] : '').
-			($thing ? '>' : '/>');
-
-		trace_add($txp_current_tag);
-		@++$txptracelevel;
-
-		if ($production_status == 'debug')
-		{
-			maxMemUsage(trim($matches[0]));
-		}
-
-		$out = '';
-
 		if (function_exists($tag))
 		{
-			$out = $tag($atts, $thing, $matches[0]);
+			$out = $tag(splat($atts), $thing);
 		}
 
 		// deprecated, remove in crockery
-		elseif (isset($pretext[$tag]))
+		elseif (isset($GLOBALS['pretext'][$tag]))
 		{
 			$out = htmlspecialchars($pretext[$tag]);
 
@@ -980,17 +1116,21 @@ $LastChangedRevision: 2777 $
 
 		else
 		{
+			$out = '';
 			trigger_error(gTxt('unknown_tag'), E_USER_WARNING);
 		}
 
-		@--$txptracelevel;
-
-		if (isset($matches[4]))
+		if ($production_status !== 'live')
 		{
-			trace_add('</txp:'.$tag.'>');
-		}
+			--$txptracelevel;
 
-		$txp_current_tag = $old_tag;
+			if (isset($thing))
+			{
+				trace_add('</txp:'.$tag.'>');
+			}
+
+			$txp_current_tag = $old_tag;
+		}
 
 		return $out;
 	}
@@ -1021,9 +1161,9 @@ $LastChangedRevision: 2777 $
 	function getCustomFields()
 	{
 		global $prefs;
+		$max = get_pref('max_custom_fields', 10);
 		$out = array();
-		$i = 0;
-		for ($i=1; $i<=10; $i++) {
+		for ($i = 1; $i <= $max; $i++) {
 			if (!empty($prefs['custom_'.$i.'_set'])) {
 				$out[$i] = strtolower($prefs['custom_'.$i.'_set']);
 			}
