@@ -6,8 +6,8 @@
 
 	Use of this software denotes acceptance of the Textpattern license agreement
 
-$HeadURL: http://svn.textpattern.com/releases/4.0.6/source/textpattern/publish/comment.php $
-$LastChangedRevision: 2776 $
+$HeadURL: https://textpattern.googlecode.com/svn/releases/4.2.0/source/textpattern/publish/comment.php $
+$LastChangedRevision: 3266 $
 
 */
 
@@ -25,7 +25,7 @@ $LastChangedRevision: 2776 $
 // -------------------------------------------------------------
 	function discuss($id)
 	{
-		$rs = safe_row('*, unix_timestamp(Posted) as uPosted', 'textpattern', 'ID='.intval($id).' and Status >= 4');
+		$rs = safe_row('*, unix_timestamp(Posted) as uPosted, unix_timestamp(LastMod) as uLastMod, unix_timestamp(Expires) as uExpires', 'textpattern', 'ID='.intval($id).' and Status >= 4');
 		if ($rs) {
 			populateArticleData($rs);
 			$result = parse_form('comments_display');
@@ -308,7 +308,7 @@ $LastChangedRevision: 2776 $
 		extract($in);
 
 		if (!checkCommentsAllowed($parentid))
-			txp_die ( gTxt('comments_closed'), '403');
+			txp_die(gTxt('comments_closed'), '403');
 
 		$ip = serverset('REMOTE_ADDR');
 
@@ -367,9 +367,7 @@ $LastChangedRevision: 2776 $
 					if ($prefs['comment_means_site_updated']) {
 						update_lastmod();
 					}
-					if ($comments_sendmail) {
-						mail_comment($message,$name,$email,$web,$parentid, $rs);
-					}
+					mail_comment($message, $name, $email, $web, $parentid, $rs);
 
 					$updated = update_comments_count($parentid);
 
@@ -538,21 +536,24 @@ $LastChangedRevision: 2776 $
 // -------------------------------------------------------------
 		function comments_help()
 	{
-		return ('<a id="txpCommentHelpLink" href="http://rpc.textpattern.com/help/index.php?item=textile_comments&language='.LANG.'" onclick="window.open(this.href, \'popupwindow\', \'width=300,height=400,scrollbars,resizable\'); return false;">'.gTxt('textile_help').'</a>');
+		return ('<a id="txpCommentHelpLink" href="http://rpc.textpattern.com/help/index.php?item=textile_comments&amp;language='.LANG.'" onclick="window.open(this.href, \'popupwindow\', \'width=300,height=400,scrollbars,resizable\'); return false;">'.gTxt('textile_help').'</a>');
 	}
 
 // -------------------------------------------------------------
 	function mail_comment($message, $cname, $cemail, $cweb, $parentid, $discussid)
 	{
-		global $sitename;
+		global $sitename, $comments_sendmail;
+
+		if (!$comments_sendmail) return;
+		$evaluator =& get_comment_evaluator();
+		if ($comments_sendmail == 2 && $evaluator->get_result() == SPAM) return;
+
 		$parentid = assert_int($parentid);
 		$discussid = assert_int($discussid);
 		$article = safe_row("Section, Posted, ID, url_title, AuthorID, Title", "textpattern", "ID = $parentid");
 		extract($article);
 		extract(safe_row("RealName, email", "txp_users", "name = '".doSlash($AuthorID)."'"));
 
-		$evaluator =& get_comment_evaluator();
-
 		$out = gTxt('greeting')." $RealName,".n.n;
 		$out .= str_replace('{title}',$Title,gTxt('comment_recorded')).n;
 		$out .= permlinkurl_id($parentid).n;
@@ -573,6 +574,7 @@ $LastChangedRevision: 2776 $
 	# deprecated, use fInput instead
 	function input($type,$name,$val,$size='',$class='',$tab='',$chkd='')
 	{
+		trigger_error(gTxt('deprecated_function_with', array('{name}' => __FUNCTION__, '{with}' => 'fInput')), E_USER_NOTICE);
 		$o = array(
 			'<input type="'.$type.'" name="'.$name.'" id="'.$name.'" value="'.$val.'"',
 			($size)	? ' size="'.$size.'"'	  : '',
