@@ -4,24 +4,28 @@ $en_gb_lang = array(
 	'admin' => array(
 		'add_new_author' => 'Add New Author',
 		'and_mailed_to' => 'and mailed to',
+		'assign_assets_to' => 'Assign user’s content to',
 		'author_deleted' => 'Author <strong>{name}</strong> deleted.',
 		'author_updated' => 'Author <strong>{name}</strong> updated.',
 		'a_message_will_be_sent_with_login' => 'A message will be sent with login information.',
 		'a_new_password_will_be_mailed' => 'A new password will be e-mailed',
+		'changeprivilege' => 'Change privilege',
 		'change_email_address' => 'Change Your E-mail Address',
 		'change_password' => 'Change Your Password',
 		'copy_editor' => 'Copy Editor',
 		'could_not_mail' => 'Could not mail',
 		'could_not_update_author' => 'Could not update author',
 		'designer' => 'Designer',
+		'edit_author' => 'Edit Author',
 		'email_changed' => 'E-mail address changed to {email}.',
-		'email_required' => 'Please provide a valid e-mail address.',
 		'error_adding_new_author' => 'Error adding new author.',
 		'freelancer' => 'Freelancer',
+		'last_login' => 'Last Login',
 		'login_name' => 'Login',
 		'log_in_at' => 'Login at',
 		'mail_it' => 'Mail it to me',
 		'managing_editor' => 'Managing Editor',
+		'must_reassign_assets' => 'Please re-assign user’s content',
 		'new_email' => 'New e-mail',
 		'new_password' => 'New password',
 		'password_changed' => 'Password changed',
@@ -37,6 +41,7 @@ $en_gb_lang = array(
 		'privileges' => 'Privileges',
 		'publisher' => 'Publisher',
 		'real_name' => 'Real Name',
+		'resetpassword' => 'Reset password',
 		'reset_author_password' => 'Reset author password',
 		'site_administration' => 'Users',
 		'staff_writer' => 'Staff writer',
@@ -51,18 +56,20 @@ $en_gb_lang = array(
 	'article' => array(
 		'advanced_options' => 'Advanced Options',
 		'article_day' => 'Day',
+		'article_expires_before_postdate' => 'Error: Article expires <strong>before</strong> post date.',
 		'article_hour' => 'Hour',
 		'article_image' => 'Article image',
 		'article_markup' => 'Article Markup',
 		'article_minute' => 'Minute',
 		'article_month' => 'Month',
-		'article_posted' => 'Article posted',
-		'article_saved' => 'Article saved',
-		'article_saved_draft' => 'Article saved as draft',
-		'article_saved_hidden' => 'Article saved as hidden',
-		'article_saved_pending' => 'Article saved as pending',
+		'article_posted' => 'Article posted.',
+		'article_saved' => 'Article saved.',
+		'article_saved_draft' => 'Article saved as draft.',
+		'article_saved_hidden' => 'Article saved as hidden.',
+		'article_saved_pending' => 'Article saved as pending.',
 		'article_second' => 'Second',
 		'article_year' => 'Year',
+		'concurrent_edit_by' => 'Article NOT saved. {author} modified the article while you were editing it. If you\'re sure, press the \'save\' button once more.',
 		'excerpt_markup' => 'Excerpt Markup',
 		'expires' => 'Expires',
 		'no_articles_recorded' => 'No articles recorded.',
@@ -74,8 +81,8 @@ $en_gb_lang = array(
 		'sort_display' => 'Sort and Display',
 		'timestamp' => 'Timestamp',
 		'url_title' => 'URL-only title',
-		'url_title_is_blank' => '(URL-only title was left blank)',
-		'url_title_is_multiple' => '(The same URL-only title is used by {count} different articles)',
+		'url_title_is_blank' => 'URL-only title was left blank.',
+		'url_title_is_multiple' => 'The same URL-only title is used by {count} different articles.',
 		'write' => 'Write',
 	),
 	'category' => array(
@@ -128,10 +135,13 @@ $en_gb_lang = array(
 		'auth_required' => 'Authorisation required.',
 		'bad_cookie' => 'Your login session has expired. Please login again.',
 		'bg-bg' => 'Български',
+		'body' => 'Body',
 		'ca-es' => 'Català',
+		'cannot_instantiate_theme' => 'Theme <strong>{name}</strong> ({class}) fails to load properly from file {path}. The Classic theme will be used as a fall-back.',
 		'changeauthor' => 'Change author',
-		'changecategory1' => 'Change Category1',
-		'changecategory2' => 'Change Category2',
+		'changecategory' => 'Change category',
+		'changecategory1' => 'Change category1',
+		'changecategory2' => 'Change category2',
 		'changecomments' => 'Change comments',
 		'changesection' => 'Change section',
 		'changestatus' => 'Change status',
@@ -189,10 +199,11 @@ $en_gb_lang = array(
 		'pt-br' => 'Português (Brasil)',
 		'pt-pt' => 'Português (Portugal)',
 		'range' => 'Range',
-		'restricted_area' => 'Restricted area',
+		'restricted_area' => 'Restricted Area',
 		'ro-ro' => 'Română',
 		'ru-ru' => 'Русский',
 		'save_new' => 'Save New',
+		'showing_search_results' => 'Showing {from} to {to} of {total}',
 		'site_slogan' => 'Site slogan',
 		'sk-sk' => 'Slovenčina',
 		'sort_value' => 'Sort Value',
@@ -225,6 +236,7 @@ $en_gb_lang = array(
 		'th-th' => 'ไทย',
 		'thumbnail' => 'Thumbnail',
 		'title_body' => 'Title & Body',
+		'title_body_excerpt' => 'Title, Body & Excerpt',
 		'txpnl2br' => 'Line Breaks Only',
 		'txprawxhtml' => 'Raw XHTML',
 		'txpstriptags' => 'Strip Tags',
@@ -380,12 +392,12 @@ $en_gb_lang = array(
 		'file_already_exists' => 'File <strong>{name}</strong> already exists.',
 		'file_cannot_rename' => 'File <strong>{name}</strong> could not be renamed.',
 		'file_category' => 'Category',
-		'file_deleted' => 'File <strong>{name}</strong> deleted.',
-		'file_delete_failed' => 'Failed to delete file',
-		'file_dir_not_writeable' => 'Warning: cannot write to file directory<br />{filedir}.<br />Please change file permissions to 777.',
+		'file_deleted' => 'File(s) <strong>{name}</strong> deleted.',
+		'file_delete_failed' => 'Failed to delete file(s)',
+		'file_dir_not_writeable' => 'Warning: cannot write to file directory<br />{filedir}.',
 		'file_download_count' => 'Download Count',
 		'file_name' => 'Name',
-		'file_not_found' => 'File not found',
+		'file_not_found' => 'File(s) not found',
 		'file_not_updated' => 'File <strong>{name}</strong> <em>not</em> updated!',
 		'file_relink' => 'Upload/Assign File',
 		'file_status' => 'File Status',
@@ -431,13 +443,13 @@ $en_gb_lang = array(
 		'create_thumbnail' => 'Create thumbnail',
 		'edit_image' => 'Edit Image',
 		'images' => 'Images',
-		'image_deleted' => 'Image <strong>{name}</strong> deleted.',
-		'image_delete_failed' => 'Image <strong>{name}</strong> could not be completely deleted.',
+		'image_deleted' => 'Image(s) <strong>{name}</strong> deleted.',
+		'image_delete_failed' => 'Image(s) <strong>{name}</strong> could not be completely deleted.',
 		'image_name' => 'Image name',
 		'image_save_error' => 'There was a problem saving image data',
 		'image_updated' => 'Image <strong>{name}</strong> updated.',
-		'image_uploaded' => 'Image <strong>{name}</strong> uploaded.',
-		'img_dir_not_writeable' => 'Warning: cannot write to image directory<br />{imgdir}.<br />Please change file permissions to 777.',
+		'image_uploaded' => 'Image(s) <strong>{name}</strong> uploaded.',
+		'img_dir_not_writeable' => 'Warning: cannot write to image directory<br />{imgdir}.',
 		'invalid_width_or_height' => 'Invalid width or height',
 		'keep_square_pixels' => 'Crop',
 		'not_saved' => '<strong>not</strong> saved!',
@@ -451,7 +463,7 @@ $en_gb_lang = array(
 		'thumb_height' => 'Height',
 		'thumb_width' => 'Width',
 		'upload_category' => 'Category',
-		'upload_dir_perms' => 'directory permissions must be 777',
+		'upload_dir_perms' => 'directory permissions need to be checked.',
 		'upload_image' => 'Upload image',
 		'upload_thumbnail' => 'Upload thumbnail',
 	),
@@ -475,14 +487,14 @@ $en_gb_lang = array(
 		'edit_links' => 'Links',
 		'linkcategory' => 'Link Categories',
 		'links' => 'Links',
-		'links_deleted' => 'Links deleted: <strong>{list}</strong>.',
+		'links_deleted' => 'Link(s) deleted: <strong>{list}</strong>.',
 		'linktext' => 'linktext',
 		'link_created' => 'Link <strong>{name}</strong> created.',
 		'link_deleted' => 'Link <strong>{name}</strong> deleted.',
 		'link_name' => 'Name',
 		'link_saved' => 'Link saved.',
 		'link_text' => 'Link text',
-		'link_updated' => 'Link <strong>{name}</strong> updated.',
+		'link_updated' => 'Link(s) <strong>{name}</strong> updated.',
 		'no_links_recorded' => 'No links recorded.',
 	),
 	'list' => array(
@@ -521,11 +533,13 @@ $en_gb_lang = array(
 	'plugin' => array(
 		'bad_plugin_code' => 'Badly formed or empty plugin code.',
 		'broken_plugin' => 'broken',
+		'changeorder' => 'Change order',
 		'edit_plugins' => 'Plugins',
 		'help' => 'Help',
 		'install' => 'Install',
 		'install_plugin' => 'Install plugin',
 		'old_plugin' => 'Old-style (text file) plugin installer',
+		'order' => 'Order',
 		'plugin' => 'Plugin',
 		'plugins' => 'Plugins',
 		'plugin_compression_unsupported' => 'Plugin decompression is not supported by your server. Contact the plugin author for an uncompressed version.',
@@ -534,6 +548,7 @@ $en_gb_lang = array(
 		'plugin_installed' => 'Plugin <strong>{name}</strong> installed.',
 		'plugin_install_failed' => 'Plugin <strong>{name}</strong> install <em>failed</em>!',
 		'plugin_modified' => 'Modified',
+		'plugin_prefs' => 'Options',
 		'plugin_saved' => 'Plugin <strong>{name}</strong> updated.',
 		'plugin_updated' => 'Plugin <strong>{name}</strong> updated.',
 		'previewing_plugin' => 'Previewing plugin:',
@@ -552,6 +567,7 @@ $en_gb_lang = array(
 		'archive_dir' => 'Archive directory',
 		'articles_use_excerpts' => 'Articles use excerpts?',
 		'attach_titles_to_permalinks' => 'Attach titles to permalinks?',
+		'auto_dst' => 'Automatically adjust <abbr title="Daylight Saving Time">DST</abbr> setting?',
 		'category_subcategory' => '/category/subcategory',
 		'check_for_txp_updates' => 'Check Updates',
 		'clean' => '/clean/',
@@ -585,9 +601,11 @@ $en_gb_lang = array(
 		'custom_9_set' => 'Custom field 9 name',
 		'czech' => 'Čeština',
 		'danish' => 'Dansk',
+		'default_event' => 'Default admin tab',
 		'dutch' => 'Nederlands',
 		'edit_preferences' => 'Preferences',
 		'edit_raw_css_by_default' => 'Use raw editing mode by default?',
+		'enable_xmlrpc_server' => 'Enable XML-RPC server?',
 		'english_gb' => 'English (GB)',
 		'english_us' => 'English (US)',
 		'experts_only' => 'experts only',
@@ -600,6 +618,8 @@ $en_gb_lang = array(
 		'from_file' => 'Install From File',
 		'from_server' => 'Install From Remote Server',
 		'gmtoffset' => 'Time Zone',
+		'ham' => 'All but spam',
+		'hours_days_ago' => 'hrs/days ago',
 		'id_title' => '/id/title',
 		'img_dir' => 'Image directory',
 		'include_email_atom' => 'Include e-mail in Atom feeds?',
@@ -653,6 +673,7 @@ $en_gb_lang = array(
 		'show_article_category_count' => 'Show article count on categories tab?',
 		'show_comment_count_in_feed' => 'Show comment count in feeds?',
 		'site_prefs' => 'Basic',
+		'smtp_from' => 'SMTP envelope sender address',
 		'spam_blacklists' => 'Spam blacklists (comma-separated)',
 		'spanish' => 'Español',
 		'swedish' => 'Swedish',
@@ -661,6 +682,7 @@ $en_gb_lang = array(
 		'tempdir' => 'Temporary directory path',
 		'textile_links' => 'Textile link descriptions by default?',
 		'thai' => 'Thai',
+		'theme_name' => 'Admin-side theme',
 		'timeoffset' => 'Time offset (hours)',
 		'title_no_widow' => 'Prevent widowed words in article titles?',
 		'title_only' => '/title',
@@ -686,11 +708,13 @@ $en_gb_lang = array(
 		'articles_found' => 'articles found',
 		'article_found' => 'article found',
 		'atom_feed_title' => 'Atom Feed',
+		'attribute_values_must_be_quoted' => 'Attribute values must be quoted',
 		'author' => 'Author',
 		'authors' => 'Authors',
 		'a_few_seconds' => 'a few seconds',
 		'blockquote' => 'Blockquote',
 		'browse' => 'Browse',
+		'bs-ba' => 'Bosanski (Bosna i Hercegovina)',
 		'bulleted_list' => 'Bulleted list',
 		'caption' => 'Caption',
 		'categories' => 'Categories',
@@ -734,6 +758,9 @@ $en_gb_lang = array(
 		'delete' => 'Delete',
 		'deleted' => 'deleted',
 		'deleted_text' => 'deleted text',
+		'deprecated_attribute' => '{name} attribute is deprecated',
+		'deprecated_function' => 'function {name} is deprecated',
+		'deprecated_function_with' => 'function {name} is deprecated: use {with} instead',
 		'deprecated_tag' => 'tag is deprecated',
 		'edit' => 'Edit',
 		'email' => 'E-mail',
@@ -754,6 +781,7 @@ $en_gb_lang = array(
 		'go_search' => 'Go to search',
 		'go_to' => 'Go to',
 		'header' => 'header',
+		'home' => 'Home',
 		'host' => 'Host',
 		'hour' => 'hour',
 		'hours' => 'hours',
@@ -772,6 +800,7 @@ $en_gb_lang = array(
 		'list_links' => 'list links',
 		'live' => 'Live',
 		'lowercase' => 'lowercase',
+		'lt-lt' => 'Lietuvių',
 		'manual' => 'Manual',
 		'message' => 'Message',
 		'message_deleted' => 'Message deleted',
@@ -834,7 +863,6 @@ $en_gb_lang = array(
 		'submit' => 'Submit',
 		'subscript' => 'subscript',
 		'superscript' => 'superscript',
-		'syndicate' => 'Syndicate',
 		'tag_error' => 'Tag error: ',
 		'textile_help' => 'Textile Help',
 		'textile_lite_help' => 'Textile Lite Help',
@@ -885,6 +913,7 @@ $en_gb_lang = array(
 		'section_used_by_article' => 'Section <strong>{name}</strong> not deleted; used by {count} article(s).',
 		'selected_by_default' => 'Selected by default',
 		'style' => 'Style',
+		'syndicate' => 'Syndicate?',
 		'uses_page' => 'Uses page',
 		'uses_style' => 'Uses style',
 	),
@@ -902,6 +931,7 @@ $en_gb_lang = array(
 		'db_doesnt_exist' => 'Database {dbname} does not exist or your specified user does not have permission to access it.',
 		'db_must_exist' => 'Note that the database you specify must already exist, Textpattern will not create it.',
 		'did_it' => 'I did it',
+		'email_required' => 'Please provide a valid e-mail address.',
 		'errors_during_install' => 'There were {num} errors during the installation. You can ask for help in the Textpattern forums.',
 		'full_path_to_txp' => 'Full server path to Textpattern',
 		'mysql' => 'MySQL',
@@ -920,6 +950,7 @@ $en_gb_lang = array(
 		'prefix_warning' => '(Use <strong>only</strong> if you require multiple installations in one database)',
 		'setup_comment_invite' => 'Comment',
 		'setup_login' => 'Choose a login name (only basic characters and spaces please)',
+		'set_temp_dir_prefs' => 'Sorry, but we failed to find a writable directory to hold temporary files.<br />Please visit the &#8220;Advanced Preferences&#8221; tab and adjust the &#8220;Temporary directory path&#8221; setting to suit your needs.',
 		'site_path' => 'Site path',
 		'site_url' => 'Site URL',
 		'table_prefix' => 'Table prefix',
@@ -945,6 +976,7 @@ $en_gb_lang = array(
 		'build' => 'Build Tag',
 		'button_text' => 'Button text',
 		'category_list_section' => 'Link to specific section?',
+		'category_tags' => 'Category',
 		'class' => 'CSS class',
 		'comments_form' => 'Comments Form',
 		'comment_details' => 'Comment Details',
@@ -995,6 +1027,7 @@ $en_gb_lang = array(
 		'searchsticky' => 'Search sticky articles?',
 		'search_input_form' => 'Search input',
 		'search_results_form' => 'Search Results',
+		'section_tags' => 'Section',
 		'showalways' => 'Show always',
 		'showcount' => 'Show count?',
 		'size_format' => 'Size format',
@@ -1011,6 +1044,7 @@ $en_gb_lang = array(
 		'tag_body' => 'Body',
 		'tag_body_excerpt' => 'Body Excerpt',
 		'tag_breadcrumb' => 'Breadcrumb',
+		'tag_category' => 'Category',
 		'tag_category1' => 'Category 1',
 		'tag_category2' => 'Category 2',
 		'tag_category_list' => 'Category List',
@@ -1049,6 +1083,8 @@ $en_gb_lang = array(
 		'tag_file_download_name' => 'File Name',
 		'tag_file_download_size' => 'File Size',
 		'tag_home' => 'Home',
+		'tag_if_category' => 'If Category',
+		'tag_if_section' => 'If Section',
 		'tag_image' => 'Image',
 		'tag_inline_' => 'Inline at end',
 		'tag_lang' => 'Language',
@@ -1107,5 +1143,5 @@ $en_gb_lang = array(
 		'wraptag' => 'Wrap tag',
 	)
 );
-$lastmod = gmdate('Y-m-d H:m:s',1201802385);
-?>
+$lastmod = gmdate('Y-m-d H:m:s',1249014846);
+?>
\ No newline at end of file
