@@ -40,7 +40,7 @@ function popWin(url, width, height, options)
 }
 
 // -------------------------------------------------------------
-// basic confirmation for potentially powerful choice 
+// basic confirmation for potentially powerful choice
 // (like deletion, for example)
 
 function verify(msg)
@@ -84,7 +84,7 @@ function selectrange()
 	var inrange = false;
 	var elem = window.document.longform.elements;
 	var cnt = elem.length;
-	
+
 	for (var i = 0; i < cnt; i++)
 	{
 		if (elem[i].name == 'selected[]')
@@ -109,7 +109,7 @@ function cleanSelects()
 {
 	var withsel = document.getElementById('withselected');
 
-	if (withsel.options[withsel.selectedIndex].value != '')
+	if (withsel && withsel.options[withsel.selectedIndex].value != '')
 	{
 		return (withsel.selectedIndex = 0);
 	}
@@ -208,22 +208,38 @@ function getElementsByClass(classname, node)
 
 function toggleDisplay(id)
 {
-	if (!document.getElementById)
-	{
-		return false;
+	var obj = $('#' + id);
+	if (obj) {
+		obj.toggle();
+		// send state of toggle pane to server
+		sendAsyncEvent(
+			{
+				event: textpattern.event,
+				step: 'save_pane_state',
+				pane: $(obj).attr('id'),
+				visible: ($(obj).css('display') == 'block')
+			}
+		);
 	}
+	return false;
+}
 
-	var obj = document.getElementById(id);
+// -------------------------------------------------------------
+// direct show/hide referred #segment; decorate parent lever
 
-	if (obj.style.display == 'none')
-	{
-		obj.style.display = 'block';
-	}
-
-	else
-	{
-		obj.style.display = 'none';
+function toggleDisplayHref()
+{
+	var href = $(this).attr('href');
+	var lever = $(this).parent('.lever');
+	if (href) toggleDisplay(href.substr(1));
+	if (lever) {
+		if ($(href+':visible').length) {
+			lever.addClass('expanded');
+		} else {
+			lever.removeClass('expanded');
+		}
 	}
+	return false;
 }
 
 // -------------------------------------------------------------
@@ -274,3 +290,20 @@ function setClassRemember(className, force)
 	setClassDisplay(className, v);
 	setClassDisplay(className+'_neg', 1-v);
 }
+
+//-------------------------------------------------------------
+// AJAX
+function sendAsyncEvent(data, fn)
+{
+	data.app_mode = 'async';
+	$.post('index.php', data, fn, 'xml');
+}
+
+//-------------------------------------------------------------
+// global admin-side behaviour
+$(document).ready(function() {
+	// disable spellchecking on all elements of type "code" in capable browsers
+	if(jQuery.browser.mozilla){$(".code").attr("spellcheck", false)};
+	// attach toggle behaviour
+	$('.lever a[class!=pophelp]').click(toggleDisplayHref);
+});
